# Check XOP instructions (maxcombos=16, maxops=3, archbits=32, seed=1)

	.text
_start:

# Tests for op VFRCZPD xmm2/mem128, xmm1  (at&t syntax)
    VFRCZPD        %xmm7,%xmm7
    VFRCZPD        %xmm0,%xmm6
    VFRCZPD        (%ebx),%xmm0
    VFRCZPD        (%esi),%xmm7
    VFRCZPD        %xmm0,%xmm0
    VFRCZPD        (%eax),%xmm7
    VFRCZPD        %xmm7,%xmm0
    VFRCZPD        %xmm1,%xmm6
    VFRCZPD        %xmm1,%xmm0
    VFRCZPD        %xmm0,%xmm7
    VFRCZPD        (%eax),%xmm6
    VFRCZPD        %xmm1,%xmm7
    VFRCZPD        (%esi),%xmm0
    VFRCZPD        (%ebx),%xmm7
    VFRCZPD        (%esi),%xmm6
    VFRCZPD        (%eax),%xmm0
# Tests for op VFRCZPD ymm2/mem256, ymm1  (at&t syntax)
    VFRCZPD        %ymm7,%ymm7
    VFRCZPD        %ymm0,%ymm6
    VFRCZPD        (%ebx),%ymm0
    VFRCZPD        (%esi),%ymm7
    VFRCZPD        %ymm0,%ymm0
    VFRCZPD        (%eax),%ymm7
    VFRCZPD        %ymm7,%ymm0
    VFRCZPD        %ymm1,%ymm6
    VFRCZPD        %ymm1,%ymm0
    VFRCZPD        %ymm0,%ymm7
    VFRCZPD        (%eax),%ymm6
    VFRCZPD        %ymm1,%ymm7
    VFRCZPD        (%esi),%ymm0
    VFRCZPD        (%ebx),%ymm7
    VFRCZPD        (%esi),%ymm6
    VFRCZPD        (%eax),%ymm0
# Tests for op VFRCZPS xmm2/mem128, xmm1  (at&t syntax)
    VFRCZPS        %xmm7,%xmm7
    VFRCZPS        %xmm0,%xmm6
    VFRCZPS        (%ebx),%xmm0
    VFRCZPS        (%esi),%xmm7
    VFRCZPS        %xmm0,%xmm0
    VFRCZPS        (%eax),%xmm7
    VFRCZPS        %xmm7,%xmm0
    VFRCZPS        %xmm1,%xmm6
    VFRCZPS        %xmm1,%xmm0
    VFRCZPS        %xmm0,%xmm7
    VFRCZPS        (%eax),%xmm6
    VFRCZPS        %xmm1,%xmm7
    VFRCZPS        (%esi),%xmm0
    VFRCZPS        (%ebx),%xmm7
    VFRCZPS        (%esi),%xmm6
    VFRCZPS        (%eax),%xmm0
# Tests for op VFRCZPS ymm2/mem256, ymm1  (at&t syntax)
    VFRCZPS        %ymm7,%ymm7
    VFRCZPS        %ymm0,%ymm6
    VFRCZPS        (%ebx),%ymm0
    VFRCZPS        (%esi),%ymm7
    VFRCZPS        %ymm0,%ymm0
    VFRCZPS        (%eax),%ymm7
    VFRCZPS        %ymm7,%ymm0
    VFRCZPS        %ymm1,%ymm6
    VFRCZPS        %ymm1,%ymm0
    VFRCZPS        %ymm0,%ymm7
    VFRCZPS        (%eax),%ymm6
    VFRCZPS        %ymm1,%ymm7
    VFRCZPS        (%esi),%ymm0
    VFRCZPS        (%ebx),%ymm7
    VFRCZPS        (%esi),%ymm6
    VFRCZPS        (%eax),%ymm0
# Tests for op VFRCZSD xmm2/mem64, xmm1  (at&t syntax)
    VFRCZSD        %xmm7,%xmm7
    VFRCZSD        %xmm0,%xmm6
    VFRCZSD        (%ebx),%xmm0
    VFRCZSD        (%esi),%xmm7
    VFRCZSD        %xmm0,%xmm0
    VFRCZSD        (%eax),%xmm7
    VFRCZSD        %xmm7,%xmm0
    VFRCZSD        %xmm1,%xmm6
    VFRCZSD        %xmm1,%xmm0
    VFRCZSD        %xmm0,%xmm7
    VFRCZSD        (%eax),%xmm6
    VFRCZSD        %xmm1,%xmm7
    VFRCZSD        (%esi),%xmm0
    VFRCZSD        (%ebx),%xmm7
    VFRCZSD        (%esi),%xmm6
    VFRCZSD        (%eax),%xmm0
# Tests for op VFRCZSS xmm2/mem32, xmm1  (at&t syntax)
    VFRCZSS        %xmm7,%xmm7
    VFRCZSS        %xmm0,%xmm6
    VFRCZSS        (%ebx),%xmm0
    VFRCZSS        (%esi),%xmm7
    VFRCZSS        %xmm0,%xmm0
    VFRCZSS        (%eax),%xmm7
    VFRCZSS        %xmm7,%xmm0
    VFRCZSS        %xmm1,%xmm6
    VFRCZSS        %xmm1,%xmm0
    VFRCZSS        %xmm0,%xmm7
    VFRCZSS        (%eax),%xmm6
    VFRCZSS        %xmm1,%xmm7
    VFRCZSS        (%esi),%xmm0
    VFRCZSS        (%ebx),%xmm7
    VFRCZSS        (%esi),%xmm6
    VFRCZSS        (%eax),%xmm0
# Tests for op VPCMOV xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCMOV         %xmm0,%xmm7,%xmm7,%xmm0
    VPCMOV         %xmm7,(%esi),%xmm0,%xmm0
    VPCMOV         %xmm1,(%esi),%xmm3,%xmm0
    VPCMOV         %xmm1,%xmm0,%xmm0,%xmm5
    VPCMOV         %xmm1,%xmm6,%xmm0,%xmm0
    VPCMOV         %xmm1,%xmm6,%xmm0,%xmm7
    VPCMOV         %xmm1,(%edx),%xmm0,%xmm7
    VPCMOV         %xmm7,%xmm0,%xmm0,%xmm7
    VPCMOV         %xmm7,(%esi),%xmm3,%xmm7
    VPCMOV         %xmm7,%xmm6,%xmm3,%xmm7
    VPCMOV         %xmm7,%xmm7,%xmm3,%xmm0
    VPCMOV         %xmm0,(%edx),%xmm3,%xmm0
    VPCMOV         %xmm1,(%edx),%xmm7,%xmm5
    VPCMOV         %xmm1,%xmm7,%xmm7,%xmm5
    VPCMOV         %xmm1,%xmm7,%xmm0,%xmm0
    VPCMOV         %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPCMOV ymm4, ymm3/mem256, ymm2, ymm1  (at&t syntax)
    VPCMOV         %ymm0,%ymm7,%ymm7,%ymm0
    VPCMOV         %ymm7,(%esi),%ymm0,%ymm0
    VPCMOV         %ymm1,(%esi),%ymm3,%ymm0
    VPCMOV         %ymm1,%ymm0,%ymm0,%ymm5
    VPCMOV         %ymm1,%ymm6,%ymm0,%ymm0
    VPCMOV         %ymm1,%ymm6,%ymm0,%ymm7
    VPCMOV         %ymm1,(%edx),%ymm0,%ymm7
    VPCMOV         %ymm7,%ymm0,%ymm0,%ymm7
    VPCMOV         %ymm7,(%esi),%ymm3,%ymm7
    VPCMOV         %ymm7,%ymm6,%ymm3,%ymm7
    VPCMOV         %ymm7,%ymm7,%ymm3,%ymm0
    VPCMOV         %ymm0,(%edx),%ymm3,%ymm0
    VPCMOV         %ymm1,(%edx),%ymm7,%ymm5
    VPCMOV         %ymm1,%ymm7,%ymm7,%ymm5
    VPCMOV         %ymm1,%ymm7,%ymm0,%ymm0
    VPCMOV         %ymm7,(%esi),%ymm3,%ymm5
# Tests for op VPCMOV xmm4/mem128, xmm3, xmm2, xmm1  (at&t syntax)
    VPCMOV         %xmm0,%xmm6,%xmm7,%xmm0
    VPCMOV         (%esi),%xmm7,%xmm0,%xmm0
    VPCMOV         (%eax),%xmm7,%xmm3,%xmm0
    VPCMOV         %xmm7,%xmm0,%xmm0,%xmm5
    VPCMOV         %xmm7,%xmm0,%xmm0,%xmm0
    VPCMOV         %xmm7,%xmm0,%xmm0,%xmm7
    VPCMOV         (%eax),%xmm6,%xmm0,%xmm7
    VPCMOV         (%esi),%xmm0,%xmm0,%xmm7
    VPCMOV         (%ebx),%xmm7,%xmm3,%xmm7
    VPCMOV         (%ebx),%xmm0,%xmm3,%xmm7
    VPCMOV         (%esi),%xmm6,%xmm3,%xmm0
    VPCMOV         %xmm1,%xmm7,%xmm3,%xmm0
    VPCMOV         (%eax),%xmm7,%xmm7,%xmm5
    VPCMOV         %xmm7,%xmm6,%xmm7,%xmm5
    VPCMOV         %xmm7,%xmm6,%xmm0,%xmm0
    VPCMOV         (%ebx),%xmm7,%xmm3,%xmm5
# Tests for op VPCMOV ymm4/mem256, ymm3, ymm2, ymm1  (at&t syntax)
    VPCMOV         %ymm0,%ymm6,%ymm7,%ymm0
    VPCMOV         (%esi),%ymm7,%ymm0,%ymm0
    VPCMOV         (%eax),%ymm7,%ymm3,%ymm0
    VPCMOV         %ymm7,%ymm0,%ymm0,%ymm5
    VPCMOV         %ymm7,%ymm0,%ymm0,%ymm0
    VPCMOV         %ymm7,%ymm0,%ymm0,%ymm7
    VPCMOV         (%eax),%ymm6,%ymm0,%ymm7
    VPCMOV         (%esi),%ymm0,%ymm0,%ymm7
    VPCMOV         (%ebx),%ymm7,%ymm3,%ymm7
    VPCMOV         (%ebx),%ymm0,%ymm3,%ymm7
    VPCMOV         (%esi),%ymm6,%ymm3,%ymm0
    VPCMOV         %ymm1,%ymm7,%ymm3,%ymm0
    VPCMOV         (%eax),%ymm7,%ymm7,%ymm5
    VPCMOV         %ymm7,%ymm6,%ymm7,%ymm5
    VPCMOV         %ymm7,%ymm6,%ymm0,%ymm0
    VPCMOV         (%ebx),%ymm7,%ymm3,%ymm5
# Tests for op VPCOMB imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMB         $0x3,(%eax),%xmm0,%xmm7
    VPCOMB         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMB         $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMB         $0x0,%xmm5,%xmm5,%xmm1
    VPCOMB         $0x0,%xmm5,%xmm0,%xmm1
    VPCOMB         $0x0,%xmm0,%xmm7,%xmm1
    VPCOMB         $0x3,%xmm0,%xmm7,%xmm7
    VPCOMB         $0x0,%xmm5,%xmm7,%xmm7
    VPCOMB         $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMB         $0x0,%xmm7,%xmm7,%xmm7
    VPCOMB         $0x3,%xmm7,%xmm0,%xmm0
    VPCOMB         $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMB         $0xFF,(%eax),%xmm5,%xmm1
    VPCOMB         $0x3,(%eax),%xmm5,%xmm1
    VPCOMB         $0x3,%xmm0,%xmm0,%xmm7
    VPCOMB         $0xFF,%xmm7,%xmm5,%xmm0
# Tests for op VPCOMD imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMD         $0x3,(%eax),%xmm0,%xmm7
    VPCOMD         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMD         $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMD         $0x0,%xmm5,%xmm5,%xmm1
    VPCOMD         $0x0,%xmm5,%xmm0,%xmm1
    VPCOMD         $0x0,%xmm0,%xmm7,%xmm1
    VPCOMD         $0x3,%xmm0,%xmm7,%xmm7
    VPCOMD         $0x0,%xmm5,%xmm7,%xmm7
    VPCOMD         $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMD         $0x0,%xmm7,%xmm7,%xmm7
    VPCOMD         $0x3,%xmm7,%xmm0,%xmm0
    VPCOMD         $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMD         $0xFF,(%eax),%xmm5,%xmm1
    VPCOMD         $0x3,(%eax),%xmm5,%xmm1
    VPCOMD         $0x3,%xmm0,%xmm0,%xmm7
    VPCOMD         $0xFF,%xmm7,%xmm5,%xmm0
# Tests for op VPCOMQ imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMQ         $0x3,(%eax),%xmm0,%xmm7
    VPCOMQ         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMQ         $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMQ         $0x0,%xmm5,%xmm5,%xmm1
    VPCOMQ         $0x0,%xmm5,%xmm0,%xmm1
    VPCOMQ         $0x0,%xmm0,%xmm7,%xmm1
    VPCOMQ         $0x3,%xmm0,%xmm7,%xmm7
    VPCOMQ         $0x0,%xmm5,%xmm7,%xmm7
    VPCOMQ         $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMQ         $0x0,%xmm7,%xmm7,%xmm7
    VPCOMQ         $0x3,%xmm7,%xmm0,%xmm0
    VPCOMQ         $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMQ         $0xFF,(%eax),%xmm5,%xmm1
    VPCOMQ         $0x3,(%eax),%xmm5,%xmm1
    VPCOMQ         $0x3,%xmm0,%xmm0,%xmm7
    VPCOMQ         $0xFF,%xmm7,%xmm5,%xmm0
# Tests for op VPCOMUB imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUB        $0x3,(%eax),%xmm0,%xmm7
    VPCOMUB        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUB        $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMUB        $0x0,%xmm5,%xmm5,%xmm1
    VPCOMUB        $0x0,%xmm5,%xmm0,%xmm1
    VPCOMUB        $0x0,%xmm0,%xmm7,%xmm1
    VPCOMUB        $0x3,%xmm0,%xmm7,%xmm7
    VPCOMUB        $0x0,%xmm5,%xmm7,%xmm7
    VPCOMUB        $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMUB        $0x0,%xmm7,%xmm7,%xmm7
    VPCOMUB        $0x3,%xmm7,%xmm0,%xmm0
    VPCOMUB        $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMUB        $0xFF,(%eax),%xmm5,%xmm1
    VPCOMUB        $0x3,(%eax),%xmm5,%xmm1
    VPCOMUB        $0x3,%xmm0,%xmm0,%xmm7
    VPCOMUB        $0xFF,%xmm7,%xmm5,%xmm0
# Tests for op VPCOMUD imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUD        $0x3,(%eax),%xmm0,%xmm7
    VPCOMUD        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUD        $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMUD        $0x0,%xmm5,%xmm5,%xmm1
    VPCOMUD        $0x0,%xmm5,%xmm0,%xmm1
    VPCOMUD        $0x0,%xmm0,%xmm7,%xmm1
    VPCOMUD        $0x3,%xmm0,%xmm7,%xmm7
    VPCOMUD        $0x0,%xmm5,%xmm7,%xmm7
    VPCOMUD        $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMUD        $0x0,%xmm7,%xmm7,%xmm7
    VPCOMUD        $0x3,%xmm7,%xmm0,%xmm0
    VPCOMUD        $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMUD        $0xFF,(%eax),%xmm5,%xmm1
    VPCOMUD        $0x3,(%eax),%xmm5,%xmm1
    VPCOMUD        $0x3,%xmm0,%xmm0,%xmm7
    VPCOMUD        $0xFF,%xmm7,%xmm5,%xmm0
# Tests for op VPCOMUQ imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUQ        $0x3,(%eax),%xmm0,%xmm7
    VPCOMUQ        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUQ        $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMUQ        $0x0,%xmm5,%xmm5,%xmm1
    VPCOMUQ        $0x0,%xmm5,%xmm0,%xmm1
    VPCOMUQ        $0x0,%xmm0,%xmm7,%xmm1
    VPCOMUQ        $0x3,%xmm0,%xmm7,%xmm7
    VPCOMUQ        $0x0,%xmm5,%xmm7,%xmm7
    VPCOMUQ        $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMUQ        $0x0,%xmm7,%xmm7,%xmm7
    VPCOMUQ        $0x3,%xmm7,%xmm0,%xmm0
    VPCOMUQ        $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMUQ        $0xFF,(%eax),%xmm5,%xmm1
    VPCOMUQ        $0x3,(%eax),%xmm5,%xmm1
    VPCOMUQ        $0x3,%xmm0,%xmm0,%xmm7
    VPCOMUQ        $0xFF,%xmm7,%xmm5,%xmm0
# Tests for op VPCOMUW imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMUW        $0x3,(%eax),%xmm0,%xmm7
    VPCOMUW        $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMUW        $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMUW        $0x0,%xmm5,%xmm5,%xmm1
    VPCOMUW        $0x0,%xmm5,%xmm0,%xmm1
    VPCOMUW        $0x0,%xmm0,%xmm7,%xmm1
    VPCOMUW        $0x3,%xmm0,%xmm7,%xmm7
    VPCOMUW        $0x0,%xmm5,%xmm7,%xmm7
    VPCOMUW        $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMUW        $0x0,%xmm7,%xmm7,%xmm7
    VPCOMUW        $0x3,%xmm7,%xmm0,%xmm0
    VPCOMUW        $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMUW        $0xFF,(%eax),%xmm5,%xmm1
    VPCOMUW        $0x3,(%eax),%xmm5,%xmm1
    VPCOMUW        $0x3,%xmm0,%xmm0,%xmm7
    VPCOMUW        $0xFF,%xmm7,%xmm5,%xmm0
# Tests for op VPCOMW imm8, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPCOMW         $0x3,(%eax),%xmm0,%xmm7
    VPCOMW         $0xFF,%xmm0,%xmm0,%xmm1
    VPCOMW         $0xFF,%xmm5,%xmm0,%xmm1
    VPCOMW         $0x0,%xmm5,%xmm5,%xmm1
    VPCOMW         $0x0,%xmm5,%xmm0,%xmm1
    VPCOMW         $0x0,%xmm0,%xmm7,%xmm1
    VPCOMW         $0x3,%xmm0,%xmm7,%xmm7
    VPCOMW         $0x0,%xmm5,%xmm7,%xmm7
    VPCOMW         $0xFF,%xmm7,%xmm7,%xmm7
    VPCOMW         $0x0,%xmm7,%xmm7,%xmm7
    VPCOMW         $0x3,%xmm7,%xmm0,%xmm0
    VPCOMW         $0xFF,%xmm7,%xmm0,%xmm1
    VPCOMW         $0xFF,(%eax),%xmm5,%xmm1
    VPCOMW         $0x3,(%eax),%xmm5,%xmm1
    VPCOMW         $0x3,%xmm0,%xmm0,%xmm7
    VPCOMW         $0xFF,%xmm7,%xmm5,%xmm0
# Testing VPERMIL2PD imm8, xmm4, xmm3/mem128, xmm2, xmm1 (at&t syntax)
    VPERMIL2PD     $0x0,%xmm5,(%eax),%xmm7,%xmm0
    VPERMIL2PD     $0x1,%xmm1,%xmm2,%xmm4,%xmm0
    VPERMIL2PD     $0x2,%xmm4,(%eax),%xmm7,%xmm2
    VPERMIL2PD     $0x3,%xmm3,(%ebx,%eax,4),%xmm4,%xmm7
    VPERMIL2PD     $0x0,%xmm3,%xmm7,%xmm0,%xmm6
    VPERMIL2PD     $0x1,%xmm7,(%esi,%edx),%xmm0,%xmm2
    VPERMIL2PD     $0x2,%xmm3,%xmm5,%xmm4,%xmm7
    VPERMIL2PD     $0x3,%xmm3,%xmm0,%xmm1,%xmm2
# Testing VPERMIL2PD imm8, xmm4/mem128, xmm3, xmm2, xmm1 (at&t syntax)
    VPERMIL2PD     $0x2,%xmm7,%xmm1,%xmm2,%xmm6
    VPERMIL2PD     $0x1,0x788(%ecx,%ebx,1),%xmm0,%xmm2,%xmm7
    VPERMIL2PD     $0x0,%xmm4,%xmm1,%xmm0,%xmm7
    VPERMIL2PD     $0x3,%xmm3,%xmm7,%xmm4,%xmm0
    VPERMIL2PD     $0x3,0x788(%ecx,%ebx,2),%xmm7,%xmm0,%xmm6
    VPERMIL2PD     $0x1,%xmm3,%xmm7,%xmm5,%xmm0
    VPERMIL2PD     $0x2,%xmm2,%xmm1,%xmm4,%xmm6
    VPERMIL2PD     $0x3,%xmm0,%xmm3,%xmm2,%xmm7
# Testing VPERMIL2PD imm8, ymm4, ymm3/mem256, ymm2, ymm1 (at&t syntax)
    VPERMIL2PD     $0x3,%ymm6,%ymm7,%ymm1,%ymm2
    VPERMIL2PD     $0x1,%ymm6,%ymm7,%ymm1,%ymm4
    VPERMIL2PD     $0x2,%ymm0,0x5(%edi,%eax,4),%ymm5,%ymm7
    VPERMIL2PD     $0x0,%ymm5,%ymm6,%ymm0,%ymm2
    VPERMIL2PD     $0x3,%ymm4,%ymm7,%ymm3,%ymm0
    VPERMIL2PD     $0x0,%ymm7,%ymm6,%ymm2,%ymm0
    VPERMIL2PD     $0x2,%ymm4,(%esi),%ymm1,%ymm7
    VPERMIL2PD     $0x1,%ymm6,%ymm0,%ymm1,%ymm7
# Testing VPERMIL2PD imm8, ymm4/mem256, ymm3, ymm2, ymm1 (at&t syntax)
    VPERMIL2PD     $0x1,(%ecx),%ymm5,%ymm7,%ymm0
    VPERMIL2PD     $0x3,(%esi,%eax,2),%ymm4,%ymm7,%ymm0
    VPERMIL2PD     $0x0,(%ecx),%ymm0,%ymm3,%ymm7
    VPERMIL2PD     $0x2,(%esi,%eax,1),%ymm2,%ymm6,%ymm7
    VPERMIL2PD     $0x0,(%ecx),%ymm0,%ymm6,%ymm1
    VPERMIL2PD     $0x2,%ymm2,%ymm3,%ymm7,%ymm0
    VPERMIL2PD     $0x3,%ymm0,%ymm2,%ymm7,%ymm1
    VPERMIL2PD     $0x1,%ymm5,%ymm0,%ymm4,%ymm7
# Testing VPERMIL2PS imm8, xmm4, xmm3/mem128, xmm2, xmm1 (at&t syntax)
    VPERMIL2PS     $0x3,%xmm3,%xmm4,%xmm0,%xmm7
    VPERMIL2PS     $0x1,%xmm0,(%eax),%xmm4,%xmm7
    VPERMIL2PS     $0x2,%xmm3,(%eax),%xmm7,%xmm7
    VPERMIL2PS     $0x3,%xmm7,(%ebx,%eax,8),%xmm7,%xmm2
    VPERMIL2PS     $0x2,%xmm7,%xmm0,%xmm7,%xmm7
    VPERMIL2PS     $0x3,%xmm7,(%esi,%edx),%xmm0,%xmm7
    VPERMIL2PS     $0x1,%xmm7,%xmm4,%xmm7,%xmm7
    VPERMIL2PS     $0x0,%xmm3,(%eax),%xmm7,%xmm2
# Testing VPERMIL2PS imm8, xmm4/mem128, xmm3, xmm2, xmm1 (at&t syntax)
    VPERMIL2PS     $0x2,(%ebx),%xmm7,%xmm7,%xmm6
    VPERMIL2PS     $0x3,(%ebx,%ebx),%xmm7,%xmm5,%xmm0
    VPERMIL2PS     $0x0,(%ebx,%ebx),%xmm1,%xmm7,%xmm6
    VPERMIL2PS     $0x2,%xmm0,%xmm1,%xmm2,%xmm7
    VPERMIL2PS     $0x2,(%ebx,%ebx),%xmm7,%xmm2,%xmm6
    VPERMIL2PS     $0x3,(%ebx,%ebx),%xmm1,%xmm7,%xmm6
    VPERMIL2PS     $0x0,(%ebx,%ebx),%xmm7,%xmm2,%xmm7
    VPERMIL2PS     $0x1,%xmm7,%xmm1,%xmm7,%xmm7
# Testing VPERMIL2PS imm8, ymm4, ymm3/mem256, ymm2, ymm1 (at&t syntax)
    VPERMIL2PS     $0x1,%ymm6,%ymm7,%ymm1,%ymm2
    VPERMIL2PS     $0x3,%ymm7,%ymm6,%ymm7,%ymm0
    VPERMIL2PS     $0x2,%ymm5,%ymm6,%ymm7,%ymm2
    VPERMIL2PS     $0x0,%ymm2,%ymm0,%ymm7,%ymm7
    VPERMIL2PS     $0x3,%ymm6,(%edi,%ecx,8),%ymm7,%ymm0
    VPERMIL2PS     $0x2,%ymm6,%ymm7,%ymm7,%ymm0
    VPERMIL2PS     $0x0,%ymm7,%ymm6,%ymm1,%ymm2
    VPERMIL2PS     $0x1,%ymm6,(%esi),%ymm1,%ymm0
# Testing VPERMIL2PS imm8, ymm4/mem256, ymm3, ymm2, ymm1 (at&t syntax)
    VPERMIL2PS     $0x2,0xC(%ebx,%eax,2),%ymm4,%ymm0,%ymm7
    VPERMIL2PS     $0x1,%ymm5,%ymm6,%ymm2,%ymm0
    VPERMIL2PS     $0x3,(%esi,%eax,1),%ymm4,%ymm6,%ymm7
    VPERMIL2PS     $0x1,(%esi,%ebx,8),%ymm3,%ymm6,%ymm0
    VPERMIL2PS     $0x0,(%eax,%ecx,2),%ymm7,%ymm0,%ymm1
    VPERMIL2PS     $0x2,%ymm6,%ymm7,%ymm7,%ymm7
    VPERMIL2PS     $0x3,%ymm4,%ymm3,%ymm2,%ymm0
    VPERMIL2PS     $0x0,%ymm0,%ymm6,%ymm7,%ymm7
# Tests for op VPHADDBD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDBD       %xmm7,%xmm7
    VPHADDBD       %xmm0,%xmm6
    VPHADDBD       (%ebx),%xmm0
    VPHADDBD       (%esi),%xmm7
    VPHADDBD       %xmm0,%xmm0
    VPHADDBD       (%eax),%xmm7
    VPHADDBD       %xmm7,%xmm0
    VPHADDBD       %xmm1,%xmm6
    VPHADDBD       %xmm1,%xmm0
    VPHADDBD       %xmm0,%xmm7
    VPHADDBD       (%eax),%xmm6
    VPHADDBD       %xmm1,%xmm7
    VPHADDBD       (%esi),%xmm0
    VPHADDBD       (%ebx),%xmm7
    VPHADDBD       (%esi),%xmm6
    VPHADDBD       (%eax),%xmm0
# Tests for op VPHADDBQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDBQ       %xmm7,%xmm7
    VPHADDBQ       %xmm0,%xmm6
    VPHADDBQ       (%ebx),%xmm0
    VPHADDBQ       (%esi),%xmm7
    VPHADDBQ       %xmm0,%xmm0
    VPHADDBQ       (%eax),%xmm7
    VPHADDBQ       %xmm7,%xmm0
    VPHADDBQ       %xmm1,%xmm6
    VPHADDBQ       %xmm1,%xmm0
    VPHADDBQ       %xmm0,%xmm7
    VPHADDBQ       (%eax),%xmm6
    VPHADDBQ       %xmm1,%xmm7
    VPHADDBQ       (%esi),%xmm0
    VPHADDBQ       (%ebx),%xmm7
    VPHADDBQ       (%esi),%xmm6
    VPHADDBQ       (%eax),%xmm0
# Tests for op VPHADDBW xmm2/mem128, xmm1  (at&t syntax)
    VPHADDBW       %xmm7,%xmm7
    VPHADDBW       %xmm0,%xmm6
    VPHADDBW       (%ebx),%xmm0
    VPHADDBW       (%esi),%xmm7
    VPHADDBW       %xmm0,%xmm0
    VPHADDBW       (%eax),%xmm7
    VPHADDBW       %xmm7,%xmm0
    VPHADDBW       %xmm1,%xmm6
    VPHADDBW       %xmm1,%xmm0
    VPHADDBW       %xmm0,%xmm7
    VPHADDBW       (%eax),%xmm6
    VPHADDBW       %xmm1,%xmm7
    VPHADDBW       (%esi),%xmm0
    VPHADDBW       (%ebx),%xmm7
    VPHADDBW       (%esi),%xmm6
    VPHADDBW       (%eax),%xmm0
# Tests for op VPHADDDQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDDQ       %xmm7,%xmm7
    VPHADDDQ       %xmm0,%xmm6
    VPHADDDQ       (%ebx),%xmm0
    VPHADDDQ       (%esi),%xmm7
    VPHADDDQ       %xmm0,%xmm0
    VPHADDDQ       (%eax),%xmm7
    VPHADDDQ       %xmm7,%xmm0
    VPHADDDQ       %xmm1,%xmm6
    VPHADDDQ       %xmm1,%xmm0
    VPHADDDQ       %xmm0,%xmm7
    VPHADDDQ       (%eax),%xmm6
    VPHADDDQ       %xmm1,%xmm7
    VPHADDDQ       (%esi),%xmm0
    VPHADDDQ       (%ebx),%xmm7
    VPHADDDQ       (%esi),%xmm6
    VPHADDDQ       (%eax),%xmm0
# Tests for op VPHADDUBD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUBD      %xmm7,%xmm7
    VPHADDUBD      %xmm0,%xmm6
    VPHADDUBD      (%ebx),%xmm0
    VPHADDUBD      (%esi),%xmm7
    VPHADDUBD      %xmm0,%xmm0
    VPHADDUBD      (%eax),%xmm7
    VPHADDUBD      %xmm7,%xmm0
    VPHADDUBD      %xmm1,%xmm6
    VPHADDUBD      %xmm1,%xmm0
    VPHADDUBD      %xmm0,%xmm7
    VPHADDUBD      (%eax),%xmm6
    VPHADDUBD      %xmm1,%xmm7
    VPHADDUBD      (%esi),%xmm0
    VPHADDUBD      (%ebx),%xmm7
    VPHADDUBD      (%esi),%xmm6
    VPHADDUBD      (%eax),%xmm0
# Tests for op VPHADDUBQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUBQ      %xmm7,%xmm7
    VPHADDUBQ      %xmm0,%xmm6
    VPHADDUBQ      (%ebx),%xmm0
    VPHADDUBQ      (%esi),%xmm7
    VPHADDUBQ      %xmm0,%xmm0
    VPHADDUBQ      (%eax),%xmm7
    VPHADDUBQ      %xmm7,%xmm0
    VPHADDUBQ      %xmm1,%xmm6
    VPHADDUBQ      %xmm1,%xmm0
    VPHADDUBQ      %xmm0,%xmm7
    VPHADDUBQ      (%eax),%xmm6
    VPHADDUBQ      %xmm1,%xmm7
    VPHADDUBQ      (%esi),%xmm0
    VPHADDUBQ      (%ebx),%xmm7
    VPHADDUBQ      (%esi),%xmm6
    VPHADDUBQ      (%eax),%xmm0
# Tests for op VPHADDUBW xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUBW      %xmm7,%xmm7
    VPHADDUBW      %xmm0,%xmm6
    VPHADDUBW      (%ebx),%xmm0
    VPHADDUBW      (%esi),%xmm7
    VPHADDUBW      %xmm0,%xmm0
    VPHADDUBW      (%eax),%xmm7
    VPHADDUBW      %xmm7,%xmm0
    VPHADDUBW      %xmm1,%xmm6
    VPHADDUBW      %xmm1,%xmm0
    VPHADDUBW      %xmm0,%xmm7
    VPHADDUBW      (%eax),%xmm6
    VPHADDUBW      %xmm1,%xmm7
    VPHADDUBW      (%esi),%xmm0
    VPHADDUBW      (%ebx),%xmm7
    VPHADDUBW      (%esi),%xmm6
    VPHADDUBW      (%eax),%xmm0
# Tests for op VPHADDUDQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUDQ      %xmm7,%xmm7
    VPHADDUDQ      %xmm0,%xmm6
    VPHADDUDQ      (%ebx),%xmm0
    VPHADDUDQ      (%esi),%xmm7
    VPHADDUDQ      %xmm0,%xmm0
    VPHADDUDQ      (%eax),%xmm7
    VPHADDUDQ      %xmm7,%xmm0
    VPHADDUDQ      %xmm1,%xmm6
    VPHADDUDQ      %xmm1,%xmm0
    VPHADDUDQ      %xmm0,%xmm7
    VPHADDUDQ      (%eax),%xmm6
    VPHADDUDQ      %xmm1,%xmm7
    VPHADDUDQ      (%esi),%xmm0
    VPHADDUDQ      (%ebx),%xmm7
    VPHADDUDQ      (%esi),%xmm6
    VPHADDUDQ      (%eax),%xmm0
# Tests for op VPHADDUWD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUWD      %xmm7,%xmm7
    VPHADDUWD      %xmm0,%xmm6
    VPHADDUWD      (%ebx),%xmm0
    VPHADDUWD      (%esi),%xmm7
    VPHADDUWD      %xmm0,%xmm0
    VPHADDUWD      (%eax),%xmm7
    VPHADDUWD      %xmm7,%xmm0
    VPHADDUWD      %xmm1,%xmm6
    VPHADDUWD      %xmm1,%xmm0
    VPHADDUWD      %xmm0,%xmm7
    VPHADDUWD      (%eax),%xmm6
    VPHADDUWD      %xmm1,%xmm7
    VPHADDUWD      (%esi),%xmm0
    VPHADDUWD      (%ebx),%xmm7
    VPHADDUWD      (%esi),%xmm6
    VPHADDUWD      (%eax),%xmm0
# Tests for op VPHADDUWQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDUWQ      %xmm7,%xmm7
    VPHADDUWQ      %xmm0,%xmm6
    VPHADDUWQ      (%ebx),%xmm0
    VPHADDUWQ      (%esi),%xmm7
    VPHADDUWQ      %xmm0,%xmm0
    VPHADDUWQ      (%eax),%xmm7
    VPHADDUWQ      %xmm7,%xmm0
    VPHADDUWQ      %xmm1,%xmm6
    VPHADDUWQ      %xmm1,%xmm0
    VPHADDUWQ      %xmm0,%xmm7
    VPHADDUWQ      (%eax),%xmm6
    VPHADDUWQ      %xmm1,%xmm7
    VPHADDUWQ      (%esi),%xmm0
    VPHADDUWQ      (%ebx),%xmm7
    VPHADDUWQ      (%esi),%xmm6
    VPHADDUWQ      (%eax),%xmm0
# Tests for op VPHADDWD xmm2/mem128, xmm1  (at&t syntax)
    VPHADDWD       %xmm7,%xmm7
    VPHADDWD       %xmm0,%xmm6
    VPHADDWD       (%ebx),%xmm0
    VPHADDWD       (%esi),%xmm7
    VPHADDWD       %xmm0,%xmm0
    VPHADDWD       (%eax),%xmm7
    VPHADDWD       %xmm7,%xmm0
    VPHADDWD       %xmm1,%xmm6
    VPHADDWD       %xmm1,%xmm0
    VPHADDWD       %xmm0,%xmm7
    VPHADDWD       (%eax),%xmm6
    VPHADDWD       %xmm1,%xmm7
    VPHADDWD       (%esi),%xmm0
    VPHADDWD       (%ebx),%xmm7
    VPHADDWD       (%esi),%xmm6
    VPHADDWD       (%eax),%xmm0
# Tests for op VPHADDWQ xmm2/mem128, xmm1  (at&t syntax)
    VPHADDWQ       %xmm7,%xmm7
    VPHADDWQ       %xmm0,%xmm6
    VPHADDWQ       (%ebx),%xmm0
    VPHADDWQ       (%esi),%xmm7
    VPHADDWQ       %xmm0,%xmm0
    VPHADDWQ       (%eax),%xmm7
    VPHADDWQ       %xmm7,%xmm0
    VPHADDWQ       %xmm1,%xmm6
    VPHADDWQ       %xmm1,%xmm0
    VPHADDWQ       %xmm0,%xmm7
    VPHADDWQ       (%eax),%xmm6
    VPHADDWQ       %xmm1,%xmm7
    VPHADDWQ       (%esi),%xmm0
    VPHADDWQ       (%ebx),%xmm7
    VPHADDWQ       (%esi),%xmm6
    VPHADDWQ       (%eax),%xmm0
# Tests for op VPHSUBBW xmm2/mem128, xmm1  (at&t syntax)
    VPHSUBBW       %xmm7,%xmm7
    VPHSUBBW       %xmm0,%xmm6
    VPHSUBBW       (%ebx),%xmm0
    VPHSUBBW       (%esi),%xmm7
    VPHSUBBW       %xmm0,%xmm0
    VPHSUBBW       (%eax),%xmm7
    VPHSUBBW       %xmm7,%xmm0
    VPHSUBBW       %xmm1,%xmm6
    VPHSUBBW       %xmm1,%xmm0
    VPHSUBBW       %xmm0,%xmm7
    VPHSUBBW       (%eax),%xmm6
    VPHSUBBW       %xmm1,%xmm7
    VPHSUBBW       (%esi),%xmm0
    VPHSUBBW       (%ebx),%xmm7
    VPHSUBBW       (%esi),%xmm6
    VPHSUBBW       (%eax),%xmm0
# Tests for op VPHSUBDQ xmm2/mem128, xmm1  (at&t syntax)
    VPHSUBDQ       %xmm7,%xmm7
    VPHSUBDQ       %xmm0,%xmm6
    VPHSUBDQ       (%ebx),%xmm0
    VPHSUBDQ       (%esi),%xmm7
    VPHSUBDQ       %xmm0,%xmm0
    VPHSUBDQ       (%eax),%xmm7
    VPHSUBDQ       %xmm7,%xmm0
    VPHSUBDQ       %xmm1,%xmm6
    VPHSUBDQ       %xmm1,%xmm0
    VPHSUBDQ       %xmm0,%xmm7
    VPHSUBDQ       (%eax),%xmm6
    VPHSUBDQ       %xmm1,%xmm7
    VPHSUBDQ       (%esi),%xmm0
    VPHSUBDQ       (%ebx),%xmm7
    VPHSUBDQ       (%esi),%xmm6
    VPHSUBDQ       (%eax),%xmm0
# Tests for op VPHSUBWD xmm2/mem128, xmm1  (at&t syntax)
    VPHSUBWD       %xmm7,%xmm7
    VPHSUBWD       %xmm0,%xmm6
    VPHSUBWD       (%ebx),%xmm0
    VPHSUBWD       (%esi),%xmm7
    VPHSUBWD       %xmm0,%xmm0
    VPHSUBWD       (%eax),%xmm7
    VPHSUBWD       %xmm7,%xmm0
    VPHSUBWD       %xmm1,%xmm6
    VPHSUBWD       %xmm1,%xmm0
    VPHSUBWD       %xmm0,%xmm7
    VPHSUBWD       (%eax),%xmm6
    VPHSUBWD       %xmm1,%xmm7
    VPHSUBWD       (%esi),%xmm0
    VPHSUBWD       (%ebx),%xmm7
    VPHSUBWD       (%esi),%xmm6
    VPHSUBWD       (%eax),%xmm0
# Tests for op VPMACSDD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSDD       %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSDD       %xmm7,(%esi),%xmm0,%xmm0
    VPMACSDD       %xmm1,(%esi),%xmm3,%xmm0
    VPMACSDD       %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSDD       %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSDD       %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSDD       %xmm1,(%edx),%xmm0,%xmm7
    VPMACSDD       %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSDD       %xmm7,(%esi),%xmm3,%xmm7
    VPMACSDD       %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSDD       %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSDD       %xmm0,(%edx),%xmm3,%xmm0
    VPMACSDD       %xmm1,(%edx),%xmm7,%xmm5
    VPMACSDD       %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSDD       %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSDD       %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSDQH xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSDQH      %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSDQH      %xmm7,(%esi),%xmm0,%xmm0
    VPMACSDQH      %xmm1,(%esi),%xmm3,%xmm0
    VPMACSDQH      %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSDQH      %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSDQH      %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSDQH      %xmm1,(%edx),%xmm0,%xmm7
    VPMACSDQH      %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSDQH      %xmm7,(%esi),%xmm3,%xmm7
    VPMACSDQH      %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSDQH      %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSDQH      %xmm0,(%edx),%xmm3,%xmm0
    VPMACSDQH      %xmm1,(%edx),%xmm7,%xmm5
    VPMACSDQH      %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSDQH      %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSDQH      %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSDQL xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSDQL      %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSDQL      %xmm7,(%esi),%xmm0,%xmm0
    VPMACSDQL      %xmm1,(%esi),%xmm3,%xmm0
    VPMACSDQL      %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSDQL      %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSDQL      %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSDQL      %xmm1,(%edx),%xmm0,%xmm7
    VPMACSDQL      %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSDQL      %xmm7,(%esi),%xmm3,%xmm7
    VPMACSDQL      %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSDQL      %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSDQL      %xmm0,(%edx),%xmm3,%xmm0
    VPMACSDQL      %xmm1,(%edx),%xmm7,%xmm5
    VPMACSDQL      %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSDQL      %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSDQL      %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSSDD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSDD      %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSSDD      %xmm7,(%esi),%xmm0,%xmm0
    VPMACSSDD      %xmm1,(%esi),%xmm3,%xmm0
    VPMACSSDD      %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSSDD      %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSSDD      %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSSDD      %xmm1,(%edx),%xmm0,%xmm7
    VPMACSSDD      %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSSDD      %xmm7,(%esi),%xmm3,%xmm7
    VPMACSSDD      %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSSDD      %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSSDD      %xmm0,(%edx),%xmm3,%xmm0
    VPMACSSDD      %xmm1,(%edx),%xmm7,%xmm5
    VPMACSSDD      %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSSDD      %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSSDD      %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSSDQH xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSDQH     %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSSDQH     %xmm7,(%esi),%xmm0,%xmm0
    VPMACSSDQH     %xmm1,(%esi),%xmm3,%xmm0
    VPMACSSDQH     %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSSDQH     %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSSDQH     %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSSDQH     %xmm1,(%edx),%xmm0,%xmm7
    VPMACSSDQH     %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSSDQH     %xmm7,(%esi),%xmm3,%xmm7
    VPMACSSDQH     %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSSDQH     %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSSDQH     %xmm0,(%edx),%xmm3,%xmm0
    VPMACSSDQH     %xmm1,(%edx),%xmm7,%xmm5
    VPMACSSDQH     %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSSDQH     %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSSDQH     %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSSDQL xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSDQL     %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSSDQL     %xmm7,(%esi),%xmm0,%xmm0
    VPMACSSDQL     %xmm1,(%esi),%xmm3,%xmm0
    VPMACSSDQL     %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSSDQL     %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSSDQL     %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSSDQL     %xmm1,(%edx),%xmm0,%xmm7
    VPMACSSDQL     %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSSDQL     %xmm7,(%esi),%xmm3,%xmm7
    VPMACSSDQL     %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSSDQL     %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSSDQL     %xmm0,(%edx),%xmm3,%xmm0
    VPMACSSDQL     %xmm1,(%edx),%xmm7,%xmm5
    VPMACSSDQL     %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSSDQL     %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSSDQL     %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSWD      %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSSWD      %xmm7,(%esi),%xmm0,%xmm0
    VPMACSSWD      %xmm1,(%esi),%xmm3,%xmm0
    VPMACSSWD      %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSSWD      %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSSWD      %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSSWD      %xmm1,(%edx),%xmm0,%xmm7
    VPMACSSWD      %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSSWD      %xmm7,(%esi),%xmm3,%xmm7
    VPMACSSWD      %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSSWD      %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSSWD      %xmm0,(%edx),%xmm3,%xmm0
    VPMACSSWD      %xmm1,(%edx),%xmm7,%xmm5
    VPMACSSWD      %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSSWD      %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSSWD      %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSSWW xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSSWW      %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSSWW      %xmm7,(%esi),%xmm0,%xmm0
    VPMACSSWW      %xmm1,(%esi),%xmm3,%xmm0
    VPMACSSWW      %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSSWW      %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSSWW      %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSSWW      %xmm1,(%edx),%xmm0,%xmm7
    VPMACSSWW      %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSSWW      %xmm7,(%esi),%xmm3,%xmm7
    VPMACSSWW      %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSSWW      %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSSWW      %xmm0,(%edx),%xmm3,%xmm0
    VPMACSSWW      %xmm1,(%edx),%xmm7,%xmm5
    VPMACSSWW      %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSSWW      %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSSWW      %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSWD       %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSWD       %xmm7,(%esi),%xmm0,%xmm0
    VPMACSWD       %xmm1,(%esi),%xmm3,%xmm0
    VPMACSWD       %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSWD       %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSWD       %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSWD       %xmm1,(%edx),%xmm0,%xmm7
    VPMACSWD       %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSWD       %xmm7,(%esi),%xmm3,%xmm7
    VPMACSWD       %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSWD       %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSWD       %xmm0,(%edx),%xmm3,%xmm0
    VPMACSWD       %xmm1,(%edx),%xmm7,%xmm5
    VPMACSWD       %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSWD       %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSWD       %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMACSWW xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMACSWW       %xmm0,%xmm7,%xmm7,%xmm0
    VPMACSWW       %xmm7,(%esi),%xmm0,%xmm0
    VPMACSWW       %xmm1,(%esi),%xmm3,%xmm0
    VPMACSWW       %xmm1,%xmm0,%xmm0,%xmm5
    VPMACSWW       %xmm1,%xmm6,%xmm0,%xmm0
    VPMACSWW       %xmm1,%xmm6,%xmm0,%xmm7
    VPMACSWW       %xmm1,(%edx),%xmm0,%xmm7
    VPMACSWW       %xmm7,%xmm0,%xmm0,%xmm7
    VPMACSWW       %xmm7,(%esi),%xmm3,%xmm7
    VPMACSWW       %xmm7,%xmm6,%xmm3,%xmm7
    VPMACSWW       %xmm7,%xmm7,%xmm3,%xmm0
    VPMACSWW       %xmm0,(%edx),%xmm3,%xmm0
    VPMACSWW       %xmm1,(%edx),%xmm7,%xmm5
    VPMACSWW       %xmm1,%xmm7,%xmm7,%xmm5
    VPMACSWW       %xmm1,%xmm7,%xmm0,%xmm0
    VPMACSWW       %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMADCSSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMADCSSWD     %xmm0,%xmm7,%xmm7,%xmm0
    VPMADCSSWD     %xmm7,(%esi),%xmm0,%xmm0
    VPMADCSSWD     %xmm1,(%esi),%xmm3,%xmm0
    VPMADCSSWD     %xmm1,%xmm0,%xmm0,%xmm5
    VPMADCSSWD     %xmm1,%xmm6,%xmm0,%xmm0
    VPMADCSSWD     %xmm1,%xmm6,%xmm0,%xmm7
    VPMADCSSWD     %xmm1,(%edx),%xmm0,%xmm7
    VPMADCSSWD     %xmm7,%xmm0,%xmm0,%xmm7
    VPMADCSSWD     %xmm7,(%esi),%xmm3,%xmm7
    VPMADCSSWD     %xmm7,%xmm6,%xmm3,%xmm7
    VPMADCSSWD     %xmm7,%xmm7,%xmm3,%xmm0
    VPMADCSSWD     %xmm0,(%edx),%xmm3,%xmm0
    VPMADCSSWD     %xmm1,(%edx),%xmm7,%xmm5
    VPMADCSSWD     %xmm1,%xmm7,%xmm7,%xmm5
    VPMADCSSWD     %xmm1,%xmm7,%xmm0,%xmm0
    VPMADCSSWD     %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPMADCSWD xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPMADCSWD      %xmm0,%xmm7,%xmm7,%xmm0
    VPMADCSWD      %xmm7,(%esi),%xmm0,%xmm0
    VPMADCSWD      %xmm1,(%esi),%xmm3,%xmm0
    VPMADCSWD      %xmm1,%xmm0,%xmm0,%xmm5
    VPMADCSWD      %xmm1,%xmm6,%xmm0,%xmm0
    VPMADCSWD      %xmm1,%xmm6,%xmm0,%xmm7
    VPMADCSWD      %xmm1,(%edx),%xmm0,%xmm7
    VPMADCSWD      %xmm7,%xmm0,%xmm0,%xmm7
    VPMADCSWD      %xmm7,(%esi),%xmm3,%xmm7
    VPMADCSWD      %xmm7,%xmm6,%xmm3,%xmm7
    VPMADCSWD      %xmm7,%xmm7,%xmm3,%xmm0
    VPMADCSWD      %xmm0,(%edx),%xmm3,%xmm0
    VPMADCSWD      %xmm1,(%edx),%xmm7,%xmm5
    VPMADCSWD      %xmm1,%xmm7,%xmm7,%xmm5
    VPMADCSWD      %xmm1,%xmm7,%xmm0,%xmm0
    VPMADCSWD      %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPPERM xmm4/mem128, xmm3, xmm2, xmm1  (at&t syntax)
    VPPERM         %xmm0,%xmm6,%xmm7,%xmm0
    VPPERM         (%esi),%xmm7,%xmm0,%xmm0
    VPPERM         (%eax),%xmm7,%xmm3,%xmm0
    VPPERM         %xmm7,%xmm0,%xmm0,%xmm5
    VPPERM         %xmm7,%xmm0,%xmm0,%xmm0
    VPPERM         %xmm7,%xmm0,%xmm0,%xmm7
    VPPERM         (%eax),%xmm6,%xmm0,%xmm7
    VPPERM         (%esi),%xmm0,%xmm0,%xmm7
    VPPERM         (%ebx),%xmm7,%xmm3,%xmm7
    VPPERM         (%ebx),%xmm0,%xmm3,%xmm7
    VPPERM         (%esi),%xmm6,%xmm3,%xmm0
    VPPERM         %xmm1,%xmm7,%xmm3,%xmm0
    VPPERM         (%eax),%xmm7,%xmm7,%xmm5
    VPPERM         %xmm7,%xmm6,%xmm7,%xmm5
    VPPERM         %xmm7,%xmm6,%xmm0,%xmm0
    VPPERM         (%ebx),%xmm7,%xmm3,%xmm5
# Tests for op VPPERM xmm4, xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPPERM         %xmm0,%xmm7,%xmm7,%xmm0
    VPPERM         %xmm7,(%esi),%xmm0,%xmm0
    VPPERM         %xmm1,(%esi),%xmm3,%xmm0
    VPPERM         %xmm1,%xmm0,%xmm0,%xmm5
    VPPERM         %xmm1,%xmm6,%xmm0,%xmm0
    VPPERM         %xmm1,%xmm6,%xmm0,%xmm7
    VPPERM         %xmm1,(%edx),%xmm0,%xmm7
    VPPERM         %xmm7,%xmm0,%xmm0,%xmm7
    VPPERM         %xmm7,(%esi),%xmm3,%xmm7
    VPPERM         %xmm7,%xmm6,%xmm3,%xmm7
    VPPERM         %xmm7,%xmm7,%xmm3,%xmm0
    VPPERM         %xmm0,(%edx),%xmm3,%xmm0
    VPPERM         %xmm1,(%edx),%xmm7,%xmm5
    VPPERM         %xmm1,%xmm7,%xmm7,%xmm5
    VPPERM         %xmm1,%xmm7,%xmm0,%xmm0
    VPPERM         %xmm7,(%esi),%xmm3,%xmm5
# Tests for op VPROTB xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTB         %xmm7,%xmm0,%xmm3
    VPROTB         %xmm7,%xmm6,%xmm7
    VPROTB         %xmm7,%xmm0,%xmm0
    VPROTB         %xmm1,(%esi),%xmm3
    VPROTB         %xmm0,%xmm7,%xmm0
    VPROTB         %xmm0,%xmm7,%xmm3
    VPROTB         %xmm0,%xmm6,%xmm0
    VPROTB         %xmm1,%xmm6,%xmm0
    VPROTB         %xmm7,%xmm7,%xmm3
    VPROTB         %xmm0,(%esi),%xmm7
    VPROTB         %xmm0,%xmm6,%xmm7
    VPROTB         %xmm7,(%esi),%xmm3
    VPROTB         %xmm7,(%edx),%xmm0
    VPROTB         %xmm1,(%esi),%xmm7
    VPROTB         %xmm1,%xmm7,%xmm0
    VPROTB         %xmm0,(%edx),%xmm3
# Tests for op VPROTB xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTB         (%ebx),%xmm0,%xmm3
    VPROTB         (%ebx),%xmm0,%xmm7
    VPROTB         (%esi),%xmm0,%xmm0
    VPROTB         (%eax),%xmm7,%xmm3
    VPROTB         %xmm1,%xmm6,%xmm0
    VPROTB         %xmm1,%xmm6,%xmm3
    VPROTB         %xmm1,%xmm0,%xmm0
    VPROTB         %xmm7,%xmm0,%xmm0
    VPROTB         (%esi),%xmm6,%xmm3
    VPROTB         %xmm1,%xmm7,%xmm7
    VPROTB         %xmm0,%xmm0,%xmm7
    VPROTB         (%ebx),%xmm7,%xmm3
    VPROTB         (%ebx),%xmm7,%xmm0
    VPROTB         (%eax),%xmm7,%xmm7
    VPROTB         (%eax),%xmm6,%xmm0
    VPROTB         %xmm1,%xmm7,%xmm3
# Tests for op VPROTB imm8, xmm2, xmm1  (at&t syntax)
    VPROTB         $0x3,%xmm5,%xmm2
    VPROTB         $-1,%xmm0,%xmm0
    VPROTB         $-1,%xmm5,%xmm7
    VPROTB         $0x0,%xmm5,%xmm7
    VPROTB         $0x0,%xmm7,%xmm7
    VPROTB         $0x0,%xmm0,%xmm2
    VPROTB         $-1,%xmm5,%xmm0
    VPROTB         $0x3,%xmm0,%xmm0
    VPROTB         $0x3,%xmm5,%xmm0
    VPROTB         $0x0,%xmm0,%xmm7
    VPROTB         $-1,%xmm7,%xmm0
    VPROTB         $-1,%xmm0,%xmm2
    VPROTB         $-1,%xmm7,%xmm2
    VPROTB         $0x3,%xmm7,%xmm7
    VPROTB         $-1,%xmm5,%xmm2
    VPROTB         $0x3,%xmm0,%xmm2
# Tests for op VPROTD xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTD         %xmm7,%xmm0,%xmm3
    VPROTD         %xmm7,%xmm6,%xmm7
    VPROTD         %xmm7,%xmm0,%xmm0
    VPROTD         %xmm1,(%esi),%xmm3
    VPROTD         %xmm0,%xmm7,%xmm0
    VPROTD         %xmm0,%xmm7,%xmm3
    VPROTD         %xmm0,%xmm6,%xmm0
    VPROTD         %xmm1,%xmm6,%xmm0
    VPROTD         %xmm7,%xmm7,%xmm3
    VPROTD         %xmm0,(%esi),%xmm7
    VPROTD         %xmm0,%xmm6,%xmm7
    VPROTD         %xmm7,(%esi),%xmm3
    VPROTD         %xmm7,(%edx),%xmm0
    VPROTD         %xmm1,(%esi),%xmm7
    VPROTD         %xmm1,%xmm7,%xmm0
    VPROTD         %xmm0,(%edx),%xmm3
# Tests for op VPROTD xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTD         (%ebx),%xmm0,%xmm3
    VPROTD         (%ebx),%xmm0,%xmm7
    VPROTD         (%esi),%xmm0,%xmm0
    VPROTD         (%eax),%xmm7,%xmm3
    VPROTD         %xmm1,%xmm6,%xmm0
    VPROTD         %xmm1,%xmm6,%xmm3
    VPROTD         %xmm1,%xmm0,%xmm0
    VPROTD         %xmm7,%xmm0,%xmm0
    VPROTD         (%esi),%xmm6,%xmm3
    VPROTD         %xmm1,%xmm7,%xmm7
    VPROTD         %xmm0,%xmm0,%xmm7
    VPROTD         (%ebx),%xmm7,%xmm3
    VPROTD         (%ebx),%xmm7,%xmm0
    VPROTD         (%eax),%xmm7,%xmm7
    VPROTD         (%eax),%xmm6,%xmm0
    VPROTD         %xmm1,%xmm7,%xmm3
# Tests for op VPROTD imm8, xmm2/mem128, xmm1  (at&t syntax)
    VPROTD         $0x0,%xmm7,%xmm7
    VPROTD         $0x0,(%ebx),%xmm7
    VPROTD         $0x0,%xmm0,%xmm5
    VPROTD         $-1,%xmm5,%xmm0
    VPROTD         $0x3,%xmm0,%xmm0
    VPROTD         $0x3,%xmm7,%xmm0
    VPROTD         $0x0,%xmm5,%xmm5
    VPROTD         $0x0,%xmm0,%xmm7
    VPROTD         $0x3,(%eax),%xmm0
    VPROTD         $-1,(%ebx),%xmm0
    VPROTD         $0x0,(%eax),%xmm7
    VPROTD         $-1,%xmm7,%xmm7
    VPROTD         $-1,%xmm5,%xmm5
    VPROTD         $-1,(%ebx),%xmm5
    VPROTD         $-1,%xmm7,%xmm0
    VPROTD         $0x3,(%eax),%xmm7
# Tests for op VPROTQ xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTQ         %xmm7,%xmm0,%xmm3
    VPROTQ         %xmm7,%xmm6,%xmm7
    VPROTQ         %xmm7,%xmm0,%xmm0
    VPROTQ         %xmm1,(%esi),%xmm3
    VPROTQ         %xmm0,%xmm7,%xmm0
    VPROTQ         %xmm0,%xmm7,%xmm3
    VPROTQ         %xmm0,%xmm6,%xmm0
    VPROTQ         %xmm1,%xmm6,%xmm0
    VPROTQ         %xmm7,%xmm7,%xmm3
    VPROTQ         %xmm0,(%esi),%xmm7
    VPROTQ         %xmm0,%xmm6,%xmm7
    VPROTQ         %xmm7,(%esi),%xmm3
    VPROTQ         %xmm7,(%edx),%xmm0
    VPROTQ         %xmm1,(%esi),%xmm7
    VPROTQ         %xmm1,%xmm7,%xmm0
    VPROTQ         %xmm0,(%edx),%xmm3
# Tests for op VPROTQ xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTQ         (%ebx),%xmm0,%xmm3
    VPROTQ         (%ebx),%xmm0,%xmm7
    VPROTQ         (%esi),%xmm0,%xmm0
    VPROTQ         (%eax),%xmm7,%xmm3
    VPROTQ         %xmm1,%xmm6,%xmm0
    VPROTQ         %xmm1,%xmm6,%xmm3
    VPROTQ         %xmm1,%xmm0,%xmm0
    VPROTQ         %xmm7,%xmm0,%xmm0
    VPROTQ         (%esi),%xmm6,%xmm3
    VPROTQ         %xmm1,%xmm7,%xmm7
    VPROTQ         %xmm0,%xmm0,%xmm7
    VPROTQ         (%ebx),%xmm7,%xmm3
    VPROTQ         (%ebx),%xmm7,%xmm0
    VPROTQ         (%eax),%xmm7,%xmm7
    VPROTQ         (%eax),%xmm6,%xmm0
    VPROTQ         %xmm1,%xmm7,%xmm3
# Tests for op VPROTQ imm8, xmm2/mem128, xmm1  (at&t syntax)
    VPROTQ         $0x0,%xmm7,%xmm7
    VPROTQ         $0x0,(%ebx),%xmm7
    VPROTQ         $0x0,%xmm0,%xmm5
    VPROTQ         $-1,%xmm5,%xmm0
    VPROTQ         $0x3,%xmm0,%xmm0
    VPROTQ         $0x3,%xmm7,%xmm0
    VPROTQ         $0x0,%xmm5,%xmm5
    VPROTQ         $0x0,%xmm0,%xmm7
    VPROTQ         $0x3,(%eax),%xmm0
    VPROTQ         $-1,(%ebx),%xmm0
    VPROTQ         $0x0,(%eax),%xmm7
    VPROTQ         $-1,%xmm7,%xmm7
    VPROTQ         $-1,%xmm5,%xmm5
    VPROTQ         $-1,(%ebx),%xmm5
    VPROTQ         $-1,%xmm7,%xmm0
    VPROTQ         $0x3,(%eax),%xmm7
# Tests for op VPROTW xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPROTW         %xmm7,%xmm0,%xmm3
    VPROTW         %xmm7,%xmm6,%xmm7
    VPROTW         %xmm7,%xmm0,%xmm0
    VPROTW         %xmm1,(%esi),%xmm3
    VPROTW         %xmm0,%xmm7,%xmm0
    VPROTW         %xmm0,%xmm7,%xmm3
    VPROTW         %xmm0,%xmm6,%xmm0
    VPROTW         %xmm1,%xmm6,%xmm0
    VPROTW         %xmm7,%xmm7,%xmm3
    VPROTW         %xmm0,(%esi),%xmm7
    VPROTW         %xmm0,%xmm6,%xmm7
    VPROTW         %xmm7,(%esi),%xmm3
    VPROTW         %xmm7,(%edx),%xmm0
    VPROTW         %xmm1,(%esi),%xmm7
    VPROTW         %xmm1,%xmm7,%xmm0
    VPROTW         %xmm0,(%edx),%xmm3
# Tests for op VPROTW xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPROTW         (%ebx),%xmm0,%xmm3
    VPROTW         (%ebx),%xmm0,%xmm7
    VPROTW         (%esi),%xmm0,%xmm0
    VPROTW         (%eax),%xmm7,%xmm3
    VPROTW         %xmm1,%xmm6,%xmm0
    VPROTW         %xmm1,%xmm6,%xmm3
    VPROTW         %xmm1,%xmm0,%xmm0
    VPROTW         %xmm7,%xmm0,%xmm0
    VPROTW         (%esi),%xmm6,%xmm3
    VPROTW         %xmm1,%xmm7,%xmm7
    VPROTW         %xmm0,%xmm0,%xmm7
    VPROTW         (%ebx),%xmm7,%xmm3
    VPROTW         (%ebx),%xmm7,%xmm0
    VPROTW         (%eax),%xmm7,%xmm7
    VPROTW         (%eax),%xmm6,%xmm0
    VPROTW         %xmm1,%xmm7,%xmm3
# Tests for op VPROTW imm8, xmm2/mem128, xmm1  (at&t syntax)
    VPROTW         $0x0,%xmm7,%xmm7
    VPROTW         $0x0,(%ebx),%xmm7
    VPROTW         $0x0,%xmm0,%xmm5
    VPROTW         $-1,%xmm5,%xmm0
    VPROTW         $0x3,%xmm0,%xmm0
    VPROTW         $0x3,%xmm7,%xmm0
    VPROTW         $0x0,%xmm5,%xmm5
    VPROTW         $0x0,%xmm0,%xmm7
    VPROTW         $0x3,(%eax),%xmm0
    VPROTW         $-1,(%ebx),%xmm0
    VPROTW         $0x0,(%eax),%xmm7
    VPROTW         $-1,%xmm7,%xmm7
    VPROTW         $-1,%xmm5,%xmm5
    VPROTW         $-1,(%ebx),%xmm5
    VPROTW         $-1,%xmm7,%xmm0
    VPROTW         $0x3,(%eax),%xmm7
# Tests for op VPSHAB xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAB         %xmm7,%xmm0,%xmm3
    VPSHAB         %xmm7,%xmm6,%xmm7
    VPSHAB         %xmm7,%xmm0,%xmm0
    VPSHAB         %xmm1,(%esi),%xmm3
    VPSHAB         %xmm0,%xmm7,%xmm0
    VPSHAB         %xmm0,%xmm7,%xmm3
    VPSHAB         %xmm0,%xmm6,%xmm0
    VPSHAB         %xmm1,%xmm6,%xmm0
    VPSHAB         %xmm7,%xmm7,%xmm3
    VPSHAB         %xmm0,(%esi),%xmm7
    VPSHAB         %xmm0,%xmm6,%xmm7
    VPSHAB         %xmm7,(%esi),%xmm3
    VPSHAB         %xmm7,(%edx),%xmm0
    VPSHAB         %xmm1,(%esi),%xmm7
    VPSHAB         %xmm1,%xmm7,%xmm0
    VPSHAB         %xmm0,(%edx),%xmm3
# Tests for op VPSHAB xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAB         (%ebx),%xmm0,%xmm3
    VPSHAB         (%ebx),%xmm0,%xmm7
    VPSHAB         (%esi),%xmm0,%xmm0
    VPSHAB         (%eax),%xmm7,%xmm3
    VPSHAB         %xmm1,%xmm6,%xmm0
    VPSHAB         %xmm1,%xmm6,%xmm3
    VPSHAB         %xmm1,%xmm0,%xmm0
    VPSHAB         %xmm7,%xmm0,%xmm0
    VPSHAB         (%esi),%xmm6,%xmm3
    VPSHAB         %xmm1,%xmm7,%xmm7
    VPSHAB         %xmm0,%xmm0,%xmm7
    VPSHAB         (%ebx),%xmm7,%xmm3
    VPSHAB         (%ebx),%xmm7,%xmm0
    VPSHAB         (%eax),%xmm7,%xmm7
    VPSHAB         (%eax),%xmm6,%xmm0
    VPSHAB         %xmm1,%xmm7,%xmm3
# Tests for op VPSHAD xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAD         %xmm7,%xmm0,%xmm3
    VPSHAD         %xmm7,%xmm6,%xmm7
    VPSHAD         %xmm7,%xmm0,%xmm0
    VPSHAD         %xmm1,(%esi),%xmm3
    VPSHAD         %xmm0,%xmm7,%xmm0
    VPSHAD         %xmm0,%xmm7,%xmm3
    VPSHAD         %xmm0,%xmm6,%xmm0
    VPSHAD         %xmm1,%xmm6,%xmm0
    VPSHAD         %xmm7,%xmm7,%xmm3
    VPSHAD         %xmm0,(%esi),%xmm7
    VPSHAD         %xmm0,%xmm6,%xmm7
    VPSHAD         %xmm7,(%esi),%xmm3
    VPSHAD         %xmm7,(%edx),%xmm0
    VPSHAD         %xmm1,(%esi),%xmm7
    VPSHAD         %xmm1,%xmm7,%xmm0
    VPSHAD         %xmm0,(%edx),%xmm3
# Tests for op VPSHAD xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAD         (%ebx),%xmm0,%xmm3
    VPSHAD         (%ebx),%xmm0,%xmm7
    VPSHAD         (%esi),%xmm0,%xmm0
    VPSHAD         (%eax),%xmm7,%xmm3
    VPSHAD         %xmm1,%xmm6,%xmm0
    VPSHAD         %xmm1,%xmm6,%xmm3
    VPSHAD         %xmm1,%xmm0,%xmm0
    VPSHAD         %xmm7,%xmm0,%xmm0
    VPSHAD         (%esi),%xmm6,%xmm3
    VPSHAD         %xmm1,%xmm7,%xmm7
    VPSHAD         %xmm0,%xmm0,%xmm7
    VPSHAD         (%ebx),%xmm7,%xmm3
    VPSHAD         (%ebx),%xmm7,%xmm0
    VPSHAD         (%eax),%xmm7,%xmm7
    VPSHAD         (%eax),%xmm6,%xmm0
    VPSHAD         %xmm1,%xmm7,%xmm3
# Tests for op VPSHAQ xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAQ         %xmm7,%xmm0,%xmm3
    VPSHAQ         %xmm7,%xmm6,%xmm7
    VPSHAQ         %xmm7,%xmm0,%xmm0
    VPSHAQ         %xmm1,(%esi),%xmm3
    VPSHAQ         %xmm0,%xmm7,%xmm0
    VPSHAQ         %xmm0,%xmm7,%xmm3
    VPSHAQ         %xmm0,%xmm6,%xmm0
    VPSHAQ         %xmm1,%xmm6,%xmm0
    VPSHAQ         %xmm7,%xmm7,%xmm3
    VPSHAQ         %xmm0,(%esi),%xmm7
    VPSHAQ         %xmm0,%xmm6,%xmm7
    VPSHAQ         %xmm7,(%esi),%xmm3
    VPSHAQ         %xmm7,(%edx),%xmm0
    VPSHAQ         %xmm1,(%esi),%xmm7
    VPSHAQ         %xmm1,%xmm7,%xmm0
    VPSHAQ         %xmm0,(%edx),%xmm3
# Tests for op VPSHAQ xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAQ         (%ebx),%xmm0,%xmm3
    VPSHAQ         (%ebx),%xmm0,%xmm7
    VPSHAQ         (%esi),%xmm0,%xmm0
    VPSHAQ         (%eax),%xmm7,%xmm3
    VPSHAQ         %xmm1,%xmm6,%xmm0
    VPSHAQ         %xmm1,%xmm6,%xmm3
    VPSHAQ         %xmm1,%xmm0,%xmm0
    VPSHAQ         %xmm7,%xmm0,%xmm0
    VPSHAQ         (%esi),%xmm6,%xmm3
    VPSHAQ         %xmm1,%xmm7,%xmm7
    VPSHAQ         %xmm0,%xmm0,%xmm7
    VPSHAQ         (%ebx),%xmm7,%xmm3
    VPSHAQ         (%ebx),%xmm7,%xmm0
    VPSHAQ         (%eax),%xmm7,%xmm7
    VPSHAQ         (%eax),%xmm6,%xmm0
    VPSHAQ         %xmm1,%xmm7,%xmm3
# Tests for op VPSHAW xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHAW         %xmm7,%xmm0,%xmm3
    VPSHAW         %xmm7,%xmm6,%xmm7
    VPSHAW         %xmm7,%xmm0,%xmm0
    VPSHAW         %xmm1,(%esi),%xmm3
    VPSHAW         %xmm0,%xmm7,%xmm0
    VPSHAW         %xmm0,%xmm7,%xmm3
    VPSHAW         %xmm0,%xmm6,%xmm0
    VPSHAW         %xmm1,%xmm6,%xmm0
    VPSHAW         %xmm7,%xmm7,%xmm3
    VPSHAW         %xmm0,(%esi),%xmm7
    VPSHAW         %xmm0,%xmm6,%xmm7
    VPSHAW         %xmm7,(%esi),%xmm3
    VPSHAW         %xmm7,(%edx),%xmm0
    VPSHAW         %xmm1,(%esi),%xmm7
    VPSHAW         %xmm1,%xmm7,%xmm0
    VPSHAW         %xmm0,(%edx),%xmm3
# Tests for op VPSHAW xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHAW         (%ebx),%xmm0,%xmm3
    VPSHAW         (%ebx),%xmm0,%xmm7
    VPSHAW         (%esi),%xmm0,%xmm0
    VPSHAW         (%eax),%xmm7,%xmm3
    VPSHAW         %xmm1,%xmm6,%xmm0
    VPSHAW         %xmm1,%xmm6,%xmm3
    VPSHAW         %xmm1,%xmm0,%xmm0
    VPSHAW         %xmm7,%xmm0,%xmm0
    VPSHAW         (%esi),%xmm6,%xmm3
    VPSHAW         %xmm1,%xmm7,%xmm7
    VPSHAW         %xmm0,%xmm0,%xmm7
    VPSHAW         (%ebx),%xmm7,%xmm3
    VPSHAW         (%ebx),%xmm7,%xmm0
    VPSHAW         (%eax),%xmm7,%xmm7
    VPSHAW         (%eax),%xmm6,%xmm0
    VPSHAW         %xmm1,%xmm7,%xmm3
# Tests for op VPSHLB xmm3, xmm2/mem128, xmm1  (at&t syntax)
    VPSHLB         %xmm7,%xmm0,%xmm3
    VPSHLB         %xmm7,%xmm6,%xmm7
    VPSHLB         %xmm7,%xmm0,%xmm0
    VPSHLB         %xmm1,(%esi),%xmm3
    VPSHLB         %xmm0,%xmm7,%xmm0
    VPSHLB         %xmm0,%xmm7,%xmm3
    VPSHLB         %xmm0,%xmm6,%xmm0
    VPSHLB         %xmm1,%xmm6,%xmm0
    VPSHLB         %xmm7,%xmm7,%xmm3
    VPSHLB         %xmm0,(%esi),%xmm7
    VPSHLB         %xmm0,%xmm6,%xmm7
    VPSHLB         %xmm7,(%esi),%xmm3
    VPSHLB         %xmm7,(%edx),%xmm0
    VPSHLB         %xmm1,(%esi),%xmm7
    VPSHLB         %xmm1,%xmm7,%xmm0
    VPSHLB         %xmm0,(%edx),%xmm3
# Tests for op VPSHLB xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLB         (%ebx),%xmm0,%xmm3
    VPSHLB         (%ebx),%xmm0,%xmm7
    VPSHLB         (%esi),%xmm0,%xmm0
    VPSHLB         (%eax),%xmm7,%xmm3
    VPSHLB         %xmm1,%xmm6,%xmm0
    VPSHLB         %xmm1,%xmm6,%xmm3
    VPSHLB         %xmm1,%xmm0,%xmm0
    VPSHLB         %xmm7,%xmm0,%xmm0
    VPSHLB         (%esi),%xmm6,%xmm3
    VPSHLB         %xmm1,%xmm7,%xmm7
    VPSHLB         %xmm0,%xmm0,%xmm7
    VPSHLB         (%ebx),%xmm7,%xmm3
    VPSHLB         (%ebx),%xmm7,%xmm0
    VPSHLB         (%eax),%xmm7,%xmm7
    VPSHLB         (%eax),%xmm6,%xmm0
    VPSHLB         %xmm1,%xmm7,%xmm3
# Tests for op VPSHLD xmm2, xmm3/mem128, xmm1  (at&t syntax)
    VPSHLD         %xmm7,%xmm0,%xmm3
    VPSHLD         %xmm7,%xmm6,%xmm7
    VPSHLD         %xmm7,%xmm0,%xmm0
    VPSHLD         %xmm1,(%esi),%xmm3
    VPSHLD         %xmm0,%xmm7,%xmm0
    VPSHLD         %xmm0,%xmm7,%xmm3
    VPSHLD         %xmm0,%xmm6,%xmm0
    VPSHLD         %xmm1,%xmm6,%xmm0
    VPSHLD         %xmm7,%xmm7,%xmm3
    VPSHLD         %xmm0,(%esi),%xmm7
    VPSHLD         %xmm0,%xmm6,%xmm7
    VPSHLD         %xmm7,(%esi),%xmm3
    VPSHLD         %xmm7,(%edx),%xmm0
    VPSHLD         %xmm1,(%esi),%xmm7
    VPSHLD         %xmm1,%xmm7,%xmm0
    VPSHLD         %xmm0,(%edx),%xmm3
# Tests for op VPSHLD xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLD         (%ebx),%xmm0,%xmm3
    VPSHLD         (%ebx),%xmm0,%xmm7
    VPSHLD         (%esi),%xmm0,%xmm0
    VPSHLD         (%eax),%xmm7,%xmm3
    VPSHLD         %xmm1,%xmm6,%xmm0
    VPSHLD         %xmm1,%xmm6,%xmm3
    VPSHLD         %xmm1,%xmm0,%xmm0
    VPSHLD         %xmm7,%xmm0,%xmm0
    VPSHLD         (%esi),%xmm6,%xmm3
    VPSHLD         %xmm1,%xmm7,%xmm7
    VPSHLD         %xmm0,%xmm0,%xmm7
    VPSHLD         (%ebx),%xmm7,%xmm3
    VPSHLD         (%ebx),%xmm7,%xmm0
    VPSHLD         (%eax),%xmm7,%xmm7
    VPSHLD         (%eax),%xmm6,%xmm0
    VPSHLD         %xmm1,%xmm7,%xmm3
# Tests for op VPSHLQ xmm2, xmm3/mem128, xmm1  (at&t syntax)
    VPSHLQ         %xmm7,%xmm0,%xmm3
    VPSHLQ         %xmm7,%xmm6,%xmm7
    VPSHLQ         %xmm7,%xmm0,%xmm0
    VPSHLQ         %xmm1,(%esi),%xmm3
    VPSHLQ         %xmm0,%xmm7,%xmm0
    VPSHLQ         %xmm0,%xmm7,%xmm3
    VPSHLQ         %xmm0,%xmm6,%xmm0
    VPSHLQ         %xmm1,%xmm6,%xmm0
    VPSHLQ         %xmm7,%xmm7,%xmm3
    VPSHLQ         %xmm0,(%esi),%xmm7
    VPSHLQ         %xmm0,%xmm6,%xmm7
    VPSHLQ         %xmm7,(%esi),%xmm3
    VPSHLQ         %xmm7,(%edx),%xmm0
    VPSHLQ         %xmm1,(%esi),%xmm7
    VPSHLQ         %xmm1,%xmm7,%xmm0
    VPSHLQ         %xmm0,(%edx),%xmm3
# Tests for op VPSHLQ xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLQ         (%ebx),%xmm0,%xmm3
    VPSHLQ         (%ebx),%xmm0,%xmm7
    VPSHLQ         (%esi),%xmm0,%xmm0
    VPSHLQ         (%eax),%xmm7,%xmm3
    VPSHLQ         %xmm1,%xmm6,%xmm0
    VPSHLQ         %xmm1,%xmm6,%xmm3
    VPSHLQ         %xmm1,%xmm0,%xmm0
    VPSHLQ         %xmm7,%xmm0,%xmm0
    VPSHLQ         (%esi),%xmm6,%xmm3
    VPSHLQ         %xmm1,%xmm7,%xmm7
    VPSHLQ         %xmm0,%xmm0,%xmm7
    VPSHLQ         (%ebx),%xmm7,%xmm3
    VPSHLQ         (%ebx),%xmm7,%xmm0
    VPSHLQ         (%eax),%xmm7,%xmm7
    VPSHLQ         (%eax),%xmm6,%xmm0
    VPSHLQ         %xmm1,%xmm7,%xmm3
# Tests for op VPSHLW xmm2, xmm3/mem128, xmm1  (at&t syntax)
    VPSHLW         %xmm7,%xmm0,%xmm3
    VPSHLW         %xmm7,%xmm6,%xmm7
    VPSHLW         %xmm7,%xmm0,%xmm0
    VPSHLW         %xmm1,(%esi),%xmm3
    VPSHLW         %xmm0,%xmm7,%xmm0
    VPSHLW         %xmm0,%xmm7,%xmm3
    VPSHLW         %xmm0,%xmm6,%xmm0
    VPSHLW         %xmm1,%xmm6,%xmm0
    VPSHLW         %xmm7,%xmm7,%xmm3
    VPSHLW         %xmm0,(%esi),%xmm7
    VPSHLW         %xmm0,%xmm6,%xmm7
    VPSHLW         %xmm7,(%esi),%xmm3
    VPSHLW         %xmm7,(%edx),%xmm0
    VPSHLW         %xmm1,(%esi),%xmm7
    VPSHLW         %xmm1,%xmm7,%xmm0
    VPSHLW         %xmm0,(%edx),%xmm3
# Tests for op VPSHLW xmm3/mem128, xmm2, xmm1  (at&t syntax)
    VPSHLW         (%ebx),%xmm0,%xmm3
    VPSHLW         (%ebx),%xmm0,%xmm7
    VPSHLW         (%esi),%xmm0,%xmm0
    VPSHLW         (%eax),%xmm7,%xmm3
    VPSHLW         %xmm1,%xmm6,%xmm0
    VPSHLW         %xmm1,%xmm6,%xmm3
    VPSHLW         %xmm1,%xmm0,%xmm0
    VPSHLW         %xmm7,%xmm0,%xmm0
    VPSHLW         (%esi),%xmm6,%xmm3
    VPSHLW         %xmm1,%xmm7,%xmm7
    VPSHLW         %xmm0,%xmm0,%xmm7
    VPSHLW         (%ebx),%xmm7,%xmm3
    VPSHLW         (%ebx),%xmm7,%xmm0
    VPSHLW         (%eax),%xmm7,%xmm7
    VPSHLW         (%eax),%xmm6,%xmm0
    VPSHLW         %xmm1,%xmm7,%xmm3
# All variants of VPCOM* aliases
    VPCOMLTB       %xmm6,%xmm0,%xmm0
    VPCOMLTB       %xmm6,%xmm0,%xmm7
    VPCOMLTB       (%edi,%eax,2),%xmm0,%xmm0
    VPCOMLTB       %xmm6,%xmm7,%xmm0
    VPCOMLTB       %xmm7,%xmm0,%xmm7
    VPCOMLTB       (%eax),%xmm7,%xmm7
    VPCOMLTB       %xmm6,%xmm4,%xmm0
    VPCOMLTB       (%edx,%ecx),%xmm0,%xmm7
    VPCOMLTD       (%eax),%xmm7,%xmm0
    VPCOMLTD       (%edi,%eax,2),%xmm4,%xmm7
    VPCOMLTD       (%eax),%xmm0,%xmm0
    VPCOMLTD       (%edi,%eax,2),%xmm4,%xmm3
    VPCOMLTD       (%edi,%eax,2),%xmm4,%xmm0
    VPCOMLTD       0x1(%eax,%edx,1),%xmm0,%xmm7
    VPCOMLTD       0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMLTD       (%edi,%eax,2),%xmm0,%xmm3
    VPCOMLTQ       (%edi,%eax,2),%xmm4,%xmm7
    VPCOMLTQ       0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMLTQ       (%edx,%ecx),%xmm0,%xmm7
    VPCOMLTQ       %xmm0,%xmm7,%xmm3
    VPCOMLTQ       0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMLTQ       (%edi,%eax,2),%xmm0,%xmm3
    VPCOMLTQ       (%eax),%xmm7,%xmm7
    VPCOMLTQ       %xmm6,%xmm0,%xmm7
    VPCOMLTUB      (%edx,%ecx),%xmm4,%xmm3
    VPCOMLTUB      (%eax),%xmm4,%xmm0
    VPCOMLTUB      %xmm7,%xmm7,%xmm3
    VPCOMLTUB      %xmm0,%xmm7,%xmm3
    VPCOMLTUB      %xmm7,%xmm7,%xmm0
    VPCOMLTUB      %xmm6,%xmm0,%xmm7
    VPCOMLTUB      %xmm7,%xmm0,%xmm3
    VPCOMLTUB      (%edx,%ecx),%xmm7,%xmm0
    VPCOMLTUD      (%edx,%ecx),%xmm7,%xmm0
    VPCOMLTUD      (%edx,%ecx),%xmm0,%xmm7
    VPCOMLTUD      (%edx,%ecx),%xmm4,%xmm7
    VPCOMLTUD      (%edx,%ecx),%xmm7,%xmm3
    VPCOMLTUD      %xmm7,%xmm4,%xmm0
    VPCOMLTUD      %xmm0,%xmm7,%xmm3
    VPCOMLTUD      0x1(%eax,%edx,1),%xmm4,%xmm3
    VPCOMLTUD      %xmm7,%xmm4,%xmm7
    VPCOMLTUQ      (%edi,%eax,2),%xmm7,%xmm0
    VPCOMLTUQ      (%eax),%xmm4,%xmm7
    VPCOMLTUQ      %xmm6,%xmm7,%xmm3
    VPCOMLTUQ      %xmm7,%xmm4,%xmm0
    VPCOMLTUQ      0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMLTUQ      (%edi,%eax,2),%xmm4,%xmm3
    VPCOMLTUQ      (%edx,%ecx),%xmm4,%xmm0
    VPCOMLTUQ      %xmm0,%xmm7,%xmm7
    VPCOMLTUW      %xmm7,%xmm0,%xmm7
    VPCOMLTUW      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMLTUW      (%edi,%eax,2),%xmm4,%xmm0
    VPCOMLTUW      (%edx,%ecx),%xmm7,%xmm0
    VPCOMLTUW      (%edi,%eax,2),%xmm0,%xmm7
    VPCOMLTUW      (%edi,%eax,2),%xmm4,%xmm7
    VPCOMLTUW      (%edx,%ecx),%xmm4,%xmm0
    VPCOMLTUW      %xmm7,%xmm7,%xmm3
    VPCOMLTW       %xmm6,%xmm0,%xmm7
    VPCOMLTW       %xmm6,%xmm4,%xmm3
    VPCOMLTW       (%eax),%xmm4,%xmm3
    VPCOMLTW       (%edi,%eax,2),%xmm0,%xmm3
    VPCOMLTW       %xmm7,%xmm4,%xmm7
    VPCOMLTW       0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMLTW       0x1(%eax,%edx,1),%xmm4,%xmm7
    VPCOMLTW       0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMLEB       (%edx,%ecx),%xmm7,%xmm0
    VPCOMLEB       %xmm6,%xmm4,%xmm0
    VPCOMLEB       (%edx,%ecx),%xmm4,%xmm0
    VPCOMLEB       0x1(%eax,%edx,1),%xmm7,%xmm7
    VPCOMLEB       0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMLEB       (%eax),%xmm7,%xmm7
    VPCOMLEB       (%edi,%eax,2),%xmm7,%xmm0
    VPCOMLEB       %xmm0,%xmm4,%xmm3
    VPCOMLED       (%eax),%xmm7,%xmm0
    VPCOMLED       (%edx,%ecx),%xmm4,%xmm7
    VPCOMLED       (%edi,%eax,2),%xmm0,%xmm3
    VPCOMLED       (%edx,%ecx),%xmm7,%xmm0
    VPCOMLED       %xmm7,%xmm7,%xmm3
    VPCOMLED       %xmm0,%xmm0,%xmm3
    VPCOMLED       0x1(%eax,%edx,1),%xmm7,%xmm7
    VPCOMLED       (%edi,%eax,2),%xmm4,%xmm3
    VPCOMLEQ       0x1(%eax,%edx,1),%xmm4,%xmm7
    VPCOMLEQ       0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMLEQ       %xmm7,%xmm0,%xmm7
    VPCOMLEQ       (%edi,%eax,2),%xmm7,%xmm7
    VPCOMLEQ       (%edx,%ecx),%xmm0,%xmm3
    VPCOMLEQ       0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMLEQ       %xmm0,%xmm0,%xmm3
    VPCOMLEQ       %xmm6,%xmm7,%xmm3
    VPCOMLEUB      %xmm0,%xmm7,%xmm0
    VPCOMLEUB      %xmm0,%xmm4,%xmm7
    VPCOMLEUB      %xmm0,%xmm7,%xmm7
    VPCOMLEUB      (%eax),%xmm0,%xmm7
    VPCOMLEUB      %xmm0,%xmm7,%xmm3
    VPCOMLEUB      %xmm7,%xmm0,%xmm7
    VPCOMLEUB      %xmm7,%xmm0,%xmm0
    VPCOMLEUB      %xmm7,%xmm7,%xmm3
    VPCOMLEUD      (%eax),%xmm7,%xmm7
    VPCOMLEUD      0x1(%eax,%edx,1),%xmm4,%xmm3
    VPCOMLEUD      (%edi,%eax,2),%xmm4,%xmm0
    VPCOMLEUD      (%edx,%ecx),%xmm7,%xmm3
    VPCOMLEUD      (%edi,%eax,2),%xmm4,%xmm3
    VPCOMLEUD      %xmm6,%xmm7,%xmm3
    VPCOMLEUD      %xmm7,%xmm0,%xmm3
    VPCOMLEUD      %xmm0,%xmm4,%xmm3
    VPCOMLEUQ      %xmm6,%xmm4,%xmm7
    VPCOMLEUQ      %xmm6,%xmm4,%xmm3
    VPCOMLEUQ      0x1(%eax,%edx,1),%xmm0,%xmm7
    VPCOMLEUQ      (%edi,%eax,2),%xmm0,%xmm0
    VPCOMLEUQ      %xmm6,%xmm0,%xmm3
    VPCOMLEUQ      (%edx,%ecx),%xmm7,%xmm0
    VPCOMLEUQ      %xmm0,%xmm4,%xmm0
    VPCOMLEUQ      (%edx,%ecx),%xmm0,%xmm7
    VPCOMLEUW      (%edx,%ecx),%xmm4,%xmm7
    VPCOMLEUW      (%edi,%eax,2),%xmm7,%xmm3
    VPCOMLEUW      %xmm6,%xmm4,%xmm0
    VPCOMLEUW      %xmm7,%xmm0,%xmm0
    VPCOMLEUW      0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMLEUW      0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMLEUW      %xmm6,%xmm7,%xmm7
    VPCOMLEUW      %xmm0,%xmm0,%xmm3
    VPCOMLEW       0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMLEW       %xmm7,%xmm4,%xmm3
    VPCOMLEW       %xmm7,%xmm0,%xmm7
    VPCOMLEW       0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMLEW       (%eax),%xmm7,%xmm0
    VPCOMLEW       (%edi,%eax,2),%xmm7,%xmm3
    VPCOMLEW       (%edx,%ecx),%xmm0,%xmm7
    VPCOMLEW       (%edx,%ecx),%xmm4,%xmm7
    VPCOMGTB       (%eax),%xmm0,%xmm0
    VPCOMGTB       (%eax),%xmm7,%xmm3
    VPCOMGTB       (%eax),%xmm0,%xmm7
    VPCOMGTB       (%edi,%eax,2),%xmm4,%xmm0
    VPCOMGTB       %xmm7,%xmm0,%xmm3
    VPCOMGTB       %xmm0,%xmm7,%xmm7
    VPCOMGTB       (%edx,%ecx),%xmm4,%xmm7
    VPCOMGTB       (%edx,%ecx),%xmm7,%xmm7
    VPCOMGTD       (%edi,%eax,2),%xmm4,%xmm0
    VPCOMGTD       (%edx,%ecx),%xmm0,%xmm3
    VPCOMGTD       (%eax),%xmm4,%xmm0
    VPCOMGTD       0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMGTD       %xmm0,%xmm0,%xmm7
    VPCOMGTD       (%edi,%eax,2),%xmm7,%xmm3
    VPCOMGTD       %xmm0,%xmm7,%xmm0
    VPCOMGTD       %xmm6,%xmm0,%xmm7
    VPCOMGTQ       (%edi,%eax,2),%xmm4,%xmm7
    VPCOMGTQ       (%edx,%ecx),%xmm4,%xmm0
    VPCOMGTQ       %xmm0,%xmm0,%xmm3
    VPCOMGTQ       %xmm0,%xmm7,%xmm7
    VPCOMGTQ       %xmm7,%xmm4,%xmm3
    VPCOMGTQ       (%edx,%ecx),%xmm7,%xmm7
    VPCOMGTQ       %xmm6,%xmm7,%xmm7
    VPCOMGTQ       %xmm6,%xmm7,%xmm3
    VPCOMGTUB      (%eax),%xmm0,%xmm0
    VPCOMGTUB      (%edx,%ecx),%xmm0,%xmm0
    VPCOMGTUB      (%edx,%ecx),%xmm7,%xmm7
    VPCOMGTUB      %xmm7,%xmm7,%xmm0
    VPCOMGTUB      %xmm6,%xmm4,%xmm7
    VPCOMGTUB      (%edi,%eax,2),%xmm0,%xmm7
    VPCOMGTUB      (%edx,%ecx),%xmm4,%xmm7
    VPCOMGTUB      (%edx,%ecx),%xmm7,%xmm0
    VPCOMGTUD      %xmm7,%xmm7,%xmm0
    VPCOMGTUD      (%edi,%eax,2),%xmm0,%xmm3
    VPCOMGTUD      %xmm6,%xmm0,%xmm0
    VPCOMGTUD      (%edi,%eax,2),%xmm0,%xmm0
    VPCOMGTUD      %xmm6,%xmm0,%xmm7
    VPCOMGTUD      0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMGTUD      %xmm0,%xmm4,%xmm3
    VPCOMGTUD      (%edx,%ecx),%xmm4,%xmm3
    VPCOMGTUQ      (%eax),%xmm0,%xmm0
    VPCOMGTUQ      (%eax),%xmm0,%xmm3
    VPCOMGTUQ      (%edx,%ecx),%xmm4,%xmm3
    VPCOMGTUQ      %xmm7,%xmm7,%xmm3
    VPCOMGTUQ      0x1(%eax,%edx,1),%xmm4,%xmm7
    VPCOMGTUQ      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMGTUQ      0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMGTUQ      %xmm7,%xmm7,%xmm0
    VPCOMGTUW      (%edx,%ecx),%xmm0,%xmm0
    VPCOMGTUW      %xmm6,%xmm0,%xmm3
    VPCOMGTUW      %xmm0,%xmm0,%xmm7
    VPCOMGTUW      %xmm6,%xmm4,%xmm7
    VPCOMGTUW      (%eax),%xmm7,%xmm7
    VPCOMGTUW      %xmm0,%xmm4,%xmm3
    VPCOMGTUW      0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMGTUW      (%edx,%ecx),%xmm4,%xmm3
    VPCOMGTW       0x1(%eax,%edx,1),%xmm4,%xmm3
    VPCOMGTW       (%edx,%ecx),%xmm0,%xmm3
    VPCOMGTW       (%edx,%ecx),%xmm7,%xmm7
    VPCOMGTW       (%eax),%xmm4,%xmm7
    VPCOMGTW       %xmm7,%xmm0,%xmm0
    VPCOMGTW       %xmm7,%xmm7,%xmm3
    VPCOMGTW       %xmm6,%xmm7,%xmm0
    VPCOMGTW       %xmm6,%xmm0,%xmm7
    VPCOMGEB       %xmm6,%xmm0,%xmm0
    VPCOMGEB       0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMGEB       (%eax),%xmm0,%xmm3
    VPCOMGEB       (%edx,%ecx),%xmm0,%xmm0
    VPCOMGEB       %xmm0,%xmm7,%xmm7
    VPCOMGEB       (%eax),%xmm4,%xmm7
    VPCOMGEB       (%edi,%eax,2),%xmm0,%xmm7
    VPCOMGEB       %xmm0,%xmm4,%xmm7
    VPCOMGED       (%eax),%xmm0,%xmm3
    VPCOMGED       (%edx,%ecx),%xmm0,%xmm7
    VPCOMGED       (%edi,%eax,2),%xmm4,%xmm7
    VPCOMGED       %xmm6,%xmm4,%xmm3
    VPCOMGED       %xmm0,%xmm0,%xmm3
    VPCOMGED       %xmm6,%xmm0,%xmm7
    VPCOMGED       %xmm0,%xmm0,%xmm7
    VPCOMGED       (%eax),%xmm7,%xmm0
    VPCOMGEQ       %xmm6,%xmm4,%xmm7
    VPCOMGEQ       %xmm7,%xmm0,%xmm0
    VPCOMGEQ       0x1(%eax,%edx,1),%xmm4,%xmm3
    VPCOMGEQ       (%edx,%ecx),%xmm4,%xmm3
    VPCOMGEQ       %xmm0,%xmm4,%xmm3
    VPCOMGEQ       0x1(%eax,%edx,1),%xmm0,%xmm7
    VPCOMGEQ       (%edi,%eax,2),%xmm4,%xmm0
    VPCOMGEQ       (%eax),%xmm7,%xmm7
    VPCOMGEUB      (%edi,%eax,2),%xmm0,%xmm0
    VPCOMGEUB      (%eax),%xmm7,%xmm3
    VPCOMGEUB      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMGEUB      0x1(%eax,%edx,1),%xmm4,%xmm3
    VPCOMGEUB      (%eax),%xmm4,%xmm3
    VPCOMGEUB      %xmm6,%xmm7,%xmm3
    VPCOMGEUB      %xmm6,%xmm7,%xmm0
    VPCOMGEUB      0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMGEUD      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMGEUD      0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMGEUD      (%edx,%ecx),%xmm0,%xmm0
    VPCOMGEUD      %xmm7,%xmm4,%xmm3
    VPCOMGEUD      %xmm0,%xmm0,%xmm3
    VPCOMGEUD      (%edx,%ecx),%xmm7,%xmm0
    VPCOMGEUD      %xmm7,%xmm4,%xmm7
    VPCOMGEUD      (%edi,%eax,2),%xmm4,%xmm3
    VPCOMGEUQ      0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMGEUQ      (%edi,%eax,2),%xmm7,%xmm7
    VPCOMGEUQ      %xmm7,%xmm4,%xmm7
    VPCOMGEUQ      (%edi,%eax,2),%xmm4,%xmm3
    VPCOMGEUQ      (%edx,%ecx),%xmm4,%xmm3
    VPCOMGEUQ      %xmm0,%xmm7,%xmm3
    VPCOMGEUQ      %xmm7,%xmm7,%xmm7
    VPCOMGEUQ      (%edx,%ecx),%xmm7,%xmm3
    VPCOMGEUW      %xmm7,%xmm7,%xmm0
    VPCOMGEUW      (%edi,%eax,2),%xmm0,%xmm3
    VPCOMGEUW      (%edx,%ecx),%xmm7,%xmm3
    VPCOMGEUW      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMGEUW      0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMGEUW      (%eax),%xmm4,%xmm0
    VPCOMGEUW      %xmm0,%xmm0,%xmm0
    VPCOMGEUW      %xmm7,%xmm7,%xmm7
    VPCOMGEW       %xmm0,%xmm0,%xmm0
    VPCOMGEW       (%eax),%xmm7,%xmm7
    VPCOMGEW       %xmm6,%xmm4,%xmm0
    VPCOMGEW       (%eax),%xmm4,%xmm0
    VPCOMGEW       %xmm0,%xmm4,%xmm3
    VPCOMGEW       0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMGEW       (%edi,%eax,2),%xmm7,%xmm7
    VPCOMGEW       %xmm6,%xmm4,%xmm3
    VPCOMEQB       (%eax),%xmm0,%xmm7
    VPCOMEQB       (%eax),%xmm4,%xmm0
    VPCOMEQB       (%edx,%ecx),%xmm0,%xmm3
    VPCOMEQB       %xmm7,%xmm7,%xmm7
    VPCOMEQB       (%edi,%eax,2),%xmm7,%xmm0
    VPCOMEQB       (%edx,%ecx),%xmm0,%xmm7
    VPCOMEQB       %xmm6,%xmm0,%xmm7
    VPCOMEQB       %xmm0,%xmm0,%xmm7
    VPCOMEQD       (%edi,%eax,2),%xmm0,%xmm7
    VPCOMEQD       (%edx,%ecx),%xmm4,%xmm7
    VPCOMEQD       0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMEQD       %xmm7,%xmm0,%xmm7
    VPCOMEQD       (%edx,%ecx),%xmm4,%xmm0
    VPCOMEQD       %xmm0,%xmm7,%xmm7
    VPCOMEQD       %xmm0,%xmm4,%xmm3
    VPCOMEQD       (%edx,%ecx),%xmm7,%xmm3
    VPCOMEQQ       (%eax),%xmm7,%xmm0
    VPCOMEQQ       %xmm6,%xmm4,%xmm0
    VPCOMEQQ       (%edi,%eax,2),%xmm4,%xmm0
    VPCOMEQQ       %xmm6,%xmm0,%xmm0
    VPCOMEQQ       (%edx,%ecx),%xmm4,%xmm0
    VPCOMEQQ       (%edi,%eax,2),%xmm0,%xmm7
    VPCOMEQQ       %xmm0,%xmm0,%xmm0
    VPCOMEQQ       0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMEQUB      %xmm7,%xmm4,%xmm0
    VPCOMEQUB      (%eax),%xmm0,%xmm3
    VPCOMEQUB      (%edx,%ecx),%xmm4,%xmm7
    VPCOMEQUB      (%edx,%ecx),%xmm7,%xmm3
    VPCOMEQUB      (%edx,%ecx),%xmm4,%xmm3
    VPCOMEQUB      %xmm6,%xmm4,%xmm3
    VPCOMEQUB      0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMEQUB      %xmm6,%xmm7,%xmm0
    VPCOMEQUD      (%eax),%xmm4,%xmm0
    VPCOMEQUD      (%edi,%eax,2),%xmm4,%xmm7
    VPCOMEQUD      (%eax),%xmm4,%xmm7
    VPCOMEQUD      %xmm6,%xmm0,%xmm3
    VPCOMEQUD      (%edi,%eax,2),%xmm4,%xmm3
    VPCOMEQUD      0x1(%eax,%edx,1),%xmm7,%xmm7
    VPCOMEQUD      %xmm7,%xmm7,%xmm7
    VPCOMEQUD      %xmm6,%xmm4,%xmm7
    VPCOMEQUQ      0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMEQUQ      %xmm6,%xmm7,%xmm7
    VPCOMEQUQ      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMEQUQ      %xmm7,%xmm0,%xmm7
    VPCOMEQUQ      %xmm7,%xmm4,%xmm0
    VPCOMEQUQ      %xmm6,%xmm7,%xmm3
    VPCOMEQUQ      %xmm6,%xmm0,%xmm3
    VPCOMEQUQ      0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMEQUW      (%edi,%eax,2),%xmm0,%xmm0
    VPCOMEQUW      (%eax),%xmm7,%xmm0
    VPCOMEQUW      (%eax),%xmm4,%xmm3
    VPCOMEQUW      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMEQUW      %xmm7,%xmm4,%xmm7
    VPCOMEQUW      (%eax),%xmm0,%xmm7
    VPCOMEQUW      (%eax),%xmm7,%xmm3
    VPCOMEQUW      %xmm0,%xmm4,%xmm3
    VPCOMEQW       (%edx,%ecx),%xmm0,%xmm3
    VPCOMEQW       (%edx,%ecx),%xmm4,%xmm0
    VPCOMEQW       (%eax),%xmm4,%xmm7
    VPCOMEQW       (%eax),%xmm7,%xmm7
    VPCOMEQW       (%edi,%eax,2),%xmm4,%xmm3
    VPCOMEQW       %xmm0,%xmm4,%xmm3
    VPCOMEQW       %xmm0,%xmm7,%xmm3
    VPCOMEQW       %xmm7,%xmm7,%xmm0
    VPCOMNEQB      0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMNEQB      (%eax),%xmm0,%xmm3
    VPCOMNEQB      (%eax),%xmm4,%xmm0
    VPCOMNEQB      0x1(%eax,%edx,1),%xmm7,%xmm7
    VPCOMNEQB      %xmm6,%xmm7,%xmm7
    VPCOMNEQB      %xmm0,%xmm7,%xmm7
    VPCOMNEQB      (%edi,%eax,2),%xmm0,%xmm3
    VPCOMNEQB      %xmm6,%xmm0,%xmm3
    VPCOMNEQD      %xmm0,%xmm7,%xmm3
    VPCOMNEQD      (%edx,%ecx),%xmm4,%xmm0
    VPCOMNEQD      (%edi,%eax,2),%xmm4,%xmm7
    VPCOMNEQD      (%eax),%xmm4,%xmm7
    VPCOMNEQD      %xmm0,%xmm4,%xmm7
    VPCOMNEQD      (%edx,%ecx),%xmm7,%xmm3
    VPCOMNEQD      %xmm7,%xmm0,%xmm3
    VPCOMNEQD      (%eax),%xmm7,%xmm3
    VPCOMNEQQ      %xmm6,%xmm7,%xmm3
    VPCOMNEQQ      %xmm0,%xmm4,%xmm0
    VPCOMNEQQ      0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMNEQQ      %xmm7,%xmm7,%xmm0
    VPCOMNEQQ      (%eax),%xmm7,%xmm0
    VPCOMNEQQ      %xmm7,%xmm4,%xmm7
    VPCOMNEQQ      (%edx,%ecx),%xmm7,%xmm7
    VPCOMNEQQ      (%edi,%eax,2),%xmm0,%xmm7
    VPCOMNEQUB     0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMNEQUB     (%edx,%ecx),%xmm0,%xmm0
    VPCOMNEQUB     (%edx,%ecx),%xmm0,%xmm3
    VPCOMNEQUB     %xmm6,%xmm4,%xmm3
    VPCOMNEQUB     %xmm0,%xmm0,%xmm7
    VPCOMNEQUB     %xmm7,%xmm0,%xmm3
    VPCOMNEQUB     %xmm7,%xmm7,%xmm0
    VPCOMNEQUB     %xmm0,%xmm7,%xmm3
    VPCOMNEQUD     %xmm0,%xmm0,%xmm0
    VPCOMNEQUD     (%edi,%eax,2),%xmm4,%xmm3
    VPCOMNEQUD     (%edx,%ecx),%xmm4,%xmm7
    VPCOMNEQUD     (%edx,%ecx),%xmm0,%xmm3
    VPCOMNEQUD     (%eax),%xmm0,%xmm0
    VPCOMNEQUD     (%eax),%xmm4,%xmm7
    VPCOMNEQUD     %xmm6,%xmm0,%xmm3
    VPCOMNEQUD     (%eax),%xmm0,%xmm7
    VPCOMNEQUQ     %xmm7,%xmm0,%xmm3
    VPCOMNEQUQ     (%edx,%ecx),%xmm0,%xmm0
    VPCOMNEQUQ     %xmm7,%xmm4,%xmm0
    VPCOMNEQUQ     %xmm0,%xmm4,%xmm3
    VPCOMNEQUQ     (%edx,%ecx),%xmm0,%xmm7
    VPCOMNEQUQ     (%edi,%eax,2),%xmm4,%xmm0
    VPCOMNEQUQ     (%eax),%xmm7,%xmm3
    VPCOMNEQUQ     0x1(%eax,%edx,1),%xmm4,%xmm3
    VPCOMNEQUW     (%eax),%xmm4,%xmm0
    VPCOMNEQUW     0x1(%eax,%edx,1),%xmm4,%xmm7
    VPCOMNEQUW     %xmm0,%xmm4,%xmm0
    VPCOMNEQUW     %xmm6,%xmm7,%xmm7
    VPCOMNEQUW     (%edx,%ecx),%xmm7,%xmm0
    VPCOMNEQUW     %xmm7,%xmm0,%xmm0
    VPCOMNEQUW     0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMNEQUW     %xmm6,%xmm0,%xmm3
    VPCOMNEQW      %xmm6,%xmm4,%xmm7
    VPCOMNEQW      (%eax),%xmm0,%xmm7
    VPCOMNEQW      %xmm7,%xmm4,%xmm7
    VPCOMNEQW      %xmm0,%xmm0,%xmm3
    VPCOMNEQW      (%eax),%xmm7,%xmm0
    VPCOMNEQW      %xmm7,%xmm7,%xmm3
    VPCOMNEQW      (%eax),%xmm0,%xmm3
    VPCOMNEQW      (%edi,%eax,2),%xmm4,%xmm7
    VPCOMFALSEB    (%edx,%ecx),%xmm7,%xmm3
    VPCOMFALSEB    0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMFALSEB    %xmm7,%xmm0,%xmm0
    VPCOMFALSEB    (%eax),%xmm7,%xmm7
    VPCOMFALSEB    (%eax),%xmm0,%xmm7
    VPCOMFALSEB    (%edi,%eax,2),%xmm0,%xmm3
    VPCOMFALSEB    0x1(%eax,%edx,1),%xmm0,%xmm7
    VPCOMFALSEB    (%eax),%xmm0,%xmm0
    VPCOMFALSED    %xmm6,%xmm0,%xmm3
    VPCOMFALSED    0x1(%eax,%edx,1),%xmm0,%xmm7
    VPCOMFALSED    0x1(%eax,%edx,1),%xmm7,%xmm7
    VPCOMFALSED    %xmm7,%xmm4,%xmm3
    VPCOMFALSED    %xmm0,%xmm4,%xmm0
    VPCOMFALSED    (%eax),%xmm0,%xmm3
    VPCOMFALSED    (%edx,%ecx),%xmm7,%xmm0
    VPCOMFALSED    (%edx,%ecx),%xmm0,%xmm0
    VPCOMFALSEQ    %xmm6,%xmm7,%xmm0
    VPCOMFALSEQ    0x1(%eax,%edx,1),%xmm0,%xmm7
    VPCOMFALSEQ    %xmm0,%xmm4,%xmm0
    VPCOMFALSEQ    (%edx,%ecx),%xmm7,%xmm0
    VPCOMFALSEQ    (%eax),%xmm7,%xmm0
    VPCOMFALSEQ    (%eax),%xmm7,%xmm3
    VPCOMFALSEQ    %xmm7,%xmm4,%xmm7
    VPCOMFALSEQ    (%edx,%ecx),%xmm4,%xmm3
    VPCOMFALSEUB   %xmm6,%xmm0,%xmm7
    VPCOMFALSEUB   (%eax),%xmm4,%xmm7
    VPCOMFALSEUB   (%edi,%eax,2),%xmm0,%xmm7
    VPCOMFALSEUB   %xmm0,%xmm4,%xmm0
    VPCOMFALSEUB   %xmm7,%xmm7,%xmm0
    VPCOMFALSEUB   (%edx,%ecx),%xmm4,%xmm3
    VPCOMFALSEUB   %xmm0,%xmm7,%xmm3
    VPCOMFALSEUB   0x1(%eax,%edx,1),%xmm4,%xmm7
    VPCOMFALSEUD   (%edx,%ecx),%xmm4,%xmm7
    VPCOMFALSEUD   (%eax),%xmm4,%xmm7
    VPCOMFALSEUD   (%eax),%xmm0,%xmm0
    VPCOMFALSEUD   %xmm7,%xmm0,%xmm0
    VPCOMFALSEUD   (%eax),%xmm4,%xmm0
    VPCOMFALSEUD   0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMFALSEUD   (%edi,%eax,2),%xmm7,%xmm0
    VPCOMFALSEUD   (%edx,%ecx),%xmm0,%xmm0
    VPCOMFALSEUQ   %xmm0,%xmm4,%xmm0
    VPCOMFALSEUQ   0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMFALSEUQ   (%eax),%xmm0,%xmm7
    VPCOMFALSEUQ   %xmm0,%xmm7,%xmm0
    VPCOMFALSEUQ   %xmm7,%xmm0,%xmm0
    VPCOMFALSEUQ   0x1(%eax,%edx,1),%xmm4,%xmm7
    VPCOMFALSEUQ   (%eax),%xmm0,%xmm3
    VPCOMFALSEUQ   %xmm7,%xmm4,%xmm0
    VPCOMFALSEUW   (%eax),%xmm7,%xmm3
    VPCOMFALSEUW   (%edx,%ecx),%xmm4,%xmm0
    VPCOMFALSEUW   %xmm6,%xmm4,%xmm7
    VPCOMFALSEUW   %xmm7,%xmm4,%xmm3
    VPCOMFALSEUW   %xmm0,%xmm7,%xmm7
    VPCOMFALSEUW   %xmm7,%xmm7,%xmm0
    VPCOMFALSEUW   0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMFALSEUW   (%eax),%xmm0,%xmm7
    VPCOMFALSEW    0x1(%eax,%edx,1),%xmm4,%xmm7
    VPCOMFALSEW    (%eax),%xmm4,%xmm3
    VPCOMFALSEW    (%edi,%eax,2),%xmm7,%xmm7
    VPCOMFALSEW    (%edi,%eax,2),%xmm0,%xmm3
    VPCOMFALSEW    (%edx,%ecx),%xmm0,%xmm7
    VPCOMFALSEW    0x1(%eax,%edx,1),%xmm0,%xmm7
    VPCOMFALSEW    %xmm6,%xmm0,%xmm7
    VPCOMFALSEW    %xmm7,%xmm0,%xmm7
    VPCOMTRUEB     (%edi,%eax,2),%xmm0,%xmm7
    VPCOMTRUEB     (%edi,%eax,2),%xmm4,%xmm3
    VPCOMTRUEB     (%eax),%xmm4,%xmm3
    VPCOMTRUEB     0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMTRUEB     0x1(%eax,%edx,1),%xmm0,%xmm3
    VPCOMTRUEB     %xmm7,%xmm4,%xmm0
    VPCOMTRUEB     %xmm7,%xmm7,%xmm3
    VPCOMTRUEB     %xmm0,%xmm7,%xmm0
    VPCOMTRUED     (%eax),%xmm7,%xmm7
    VPCOMTRUED     %xmm6,%xmm4,%xmm0
    VPCOMTRUED     %xmm0,%xmm7,%xmm7
    VPCOMTRUED     (%edx,%ecx),%xmm4,%xmm0
    VPCOMTRUED     0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMTRUED     %xmm7,%xmm0,%xmm7
    VPCOMTRUED     (%eax),%xmm0,%xmm7
    VPCOMTRUED     (%edx,%ecx),%xmm0,%xmm3
    VPCOMTRUEQ     (%edi,%eax,2),%xmm7,%xmm3
    VPCOMTRUEQ     %xmm7,%xmm7,%xmm3
    VPCOMTRUEQ     %xmm6,%xmm4,%xmm7
    VPCOMTRUEQ     (%edi,%eax,2),%xmm7,%xmm0
    VPCOMTRUEQ     %xmm0,%xmm4,%xmm0
    VPCOMTRUEQ     %xmm7,%xmm0,%xmm0
    VPCOMTRUEQ     (%edi,%eax,2),%xmm0,%xmm0
    VPCOMTRUEQ     (%eax),%xmm0,%xmm7
    VPCOMTRUEUB    (%edx,%ecx),%xmm0,%xmm7
    VPCOMTRUEUB    (%edi,%eax,2),%xmm7,%xmm3
    VPCOMTRUEUB    0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMTRUEUB    0x1(%eax,%edx,1),%xmm7,%xmm3
    VPCOMTRUEUB    0x1(%eax,%edx,1),%xmm4,%xmm0
    VPCOMTRUEUB    (%eax),%xmm7,%xmm7
    VPCOMTRUEUB    (%edi,%eax,2),%xmm0,%xmm0
    VPCOMTRUEUB    %xmm6,%xmm0,%xmm3
    VPCOMTRUEUD    (%edi,%eax,2),%xmm0,%xmm7
    VPCOMTRUEUD    %xmm7,%xmm4,%xmm3
    VPCOMTRUEUD    %xmm7,%xmm4,%xmm0
    VPCOMTRUEUD    (%edi,%eax,2),%xmm4,%xmm3
    VPCOMTRUEUD    (%eax),%xmm0,%xmm7
    VPCOMTRUEUD    %xmm6,%xmm7,%xmm0
    VPCOMTRUEUD    0x1(%eax,%edx,1),%xmm7,%xmm0
    VPCOMTRUEUD    (%edi,%eax,2),%xmm0,%xmm0
    VPCOMTRUEUQ    (%edx,%ecx),%xmm7,%xmm7
    VPCOMTRUEUQ    (%eax),%xmm0,%xmm7
    VPCOMTRUEUQ    0x1(%eax,%edx,1),%xmm7,%xmm7
    VPCOMTRUEUQ    %xmm7,%xmm0,%xmm7
    VPCOMTRUEUQ    (%eax),%xmm7,%xmm0
    VPCOMTRUEUQ    (%edi,%eax,2),%xmm0,%xmm0
    VPCOMTRUEUQ    (%edx,%ecx),%xmm7,%xmm0
    VPCOMTRUEUQ    %xmm0,%xmm0,%xmm0
    VPCOMTRUEUW    (%edx,%ecx),%xmm0,%xmm3
    VPCOMTRUEUW    (%edi,%eax,2),%xmm7,%xmm7
    VPCOMTRUEUW    0x1(%eax,%edx,1),%xmm0,%xmm0
    VPCOMTRUEUW    %xmm7,%xmm0,%xmm0
    VPCOMTRUEUW    %xmm0,%xmm7,%xmm7
    VPCOMTRUEUW    %xmm0,%xmm4,%xmm3
    VPCOMTRUEUW    (%eax),%xmm7,%xmm7
    VPCOMTRUEUW    %xmm0,%xmm0,%xmm7
    VPCOMTRUEW     %xmm6,%xmm0,%xmm0
    VPCOMTRUEW     (%edx,%ecx),%xmm7,%xmm0
    VPCOMTRUEW     (%edx,%ecx),%xmm7,%xmm3
    VPCOMTRUEW     (%edx,%ecx),%xmm4,%xmm7
    VPCOMTRUEW     (%eax),%xmm4,%xmm7
    VPCOMTRUEW     %xmm6,%xmm7,%xmm7
    VPCOMTRUEW     %xmm0,%xmm4,%xmm3
    VPCOMTRUEW     (%edx,%ecx),%xmm0,%xmm3
